<?xml version='1.0' encoding='UTF-8' ?>
<!DOCTYPE book PUBLIC "-//OASIS//DTD DocBook XML V4.4//EN"
"http://www.oasis-open.org/docbook/xml/4.4/docbookx.dtd">

<!--
M4 MACROS
The examples in the Pantry manual are built automatically
using GNU M4. m4 must be run using the -P option. -P may not
exist in non-GNU m4 programs.

Because of the way m4 works, the macros themselves do
not actually appear in the XML file. (I could strip out
these comments too but that is too much of a bother.) To see the
actual m4 macros, you can examine the pantry_user_guide.m4 file,
which is included in the source tarball in the docs directory.

The m4 command used to generate the XML file must set two macros
using the -D option: pb_version and pb_release_date.

m4_changequote(`{', `}')

Strips the beginning of each line of extra spaces.
m4_define({pb_strip}, {m4_patsubst({$1}, {^ *}, {})})

Wraps text inside XML tags, where $1 is the tag name desired
and $2 is the text to wrap.
m4_define({pb_tag}, {<$1>$2</$1>})

Wraps text inside a CDATA tag.
m4_define({pb_cdata}, {<![CDATA[$1]]>})

Emit a newline.
m4_define({pb_newline}, {
})

Fatal errors!
m4_define({pb_fatal_error},
          {m4_errprint({fatal error: $1 failed}pb_newline)m4_m4exit({1})})

Takes text on $1 to be used as an example command line. Strips each
line of leading spaces, and wraps the result in userinput tags.
Also provides a $ for a prompt, wrapped in prompt tags.
m4_define({pb_command}, {pb_tag({prompt}, 
                                {$ })pb_tag({userinput},
                                            {pb_cdata({pb_strip({$1})})})})

Expands to result of system command, which is $1. This expansion
always occurs. If the shell command returned a non-zero value, then
do a fatal error.
m4_define({pb_command_sub},
          {m4_esyscmd({$1})m4_ifelse(m4_sysval,
             0,
             {},
             {pb_fatal_error({$1})})})

Takes text on $1, runs it in a shell, and grabs output; wraps
output in computeroutput tags.
m4_define({pb_output}, {pb_tag({computeroutput},
                               {pb_cdata({pb_command_sub({$1})})})})

Takes text to use as command line, and provides both input
and output wrapped in screen tags.
m4_define({pb_verbatim}, 
          {pb_tag({screen},
                  {pb_command({$1 pb_newline})pb_output({$1})})})

Takes two strings. The first is the command text to actually run,
and the second is the command text to actually show in the result.
m4_define({pb_verbatim_sub},
          {pb_tag({screen},
                  {pb_command({$2 pb_newline})pb_output({$1})})})

Run a shell command given in $1. Do a fatal error if it failed;
otherwise this macro expands to nothing. It does not expand to the
shell command's output. The quoting on the conditional macro is
strange; I do not understand it but it works.
m4_define({pb_sh},
          {m4_ifelse(m4_syscmd({$1})m4_sysval,
                     0,
                     {},
                     {pb_fatal_error({$1}pb_newline)})})

I hate this, but no other solution is immediately apparent
m4_define({pb_corn_bread_instructions}, {Heat oven to 400
degrees F. Grease 8- or 9-inch pan. Combine
dry ingredients. Stir in milk, oil, and
egg, mixing just until dry ingredients are
moistened. Pour batter into prepared pan.
Bake 20 to 25 minutes or until light golden
brown and wooden pick inserted in center
comes out clean. Serve warm.})

Make sure there is no server running. Next macro is intentionally 
outside the XML comments because you can't stick two dashes inside
XML comments -->
pb_sh({! pantry --status >/dev/null 2>&1})

<book>
<bookinfo>
    <title>Pantry User Guide</title>
    <releaseinfo>Version pb_version released pb_release_date.</releaseinfo>
    <author><firstname>Omari</firstname><surname>Norman</surname></author>
    <legalnotice>

        <para>Copyright 2007-pb_release_year Omari Norman.</para>

        <para> Permission is hereby granted, free of charge, to any
            person obtaining a copy of this software and associated
            documentation files (the "Software"), to deal in the
            Software without restriction, including without
            limitation the rights to use, copy, modify, merge,
            publish, distribute, sublicense, and/or sell copies of
            the Software, and to permit persons to whom the Software
            is furnished to do so, subject to the following
            conditions: </para>

        <para>The above copyright notice and this permission notice
            shall be included in all copies or substantial portions
            of the Software.</para>

        <para>THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
            KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
            WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
            PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
            OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
            OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
            OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
            SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
            SOFTWARE.</para>

        <!-- Don't put the hyperlinks in this paragraph in ulink
        tags because the refentry-to-man does not know how to deal
        with them. -->
        
        <para> Data in the <filename>starter_database</filename>
            file is derived from U.S. Department of Agriculture,
            Agricultural Research Service. 2008.  USDA National
            Nutrient Database for Standard Reference, Release 21.
            Nutrient Data Laboratory Home Page:
            http://www.ars.usda.gov/ba/bhnrc/ndl This data is in the
            public domain and there is no copyright, see
            http://www.ars.usda.gov/Main/docs.htm?docid=6233#copyright</para>

    </legalnotice>
</bookinfo>

<preface id="about_pantry">
    <title>About Pantry</title>

    <para>Pantry is a command-line oriented nutrient analysis
        program. It can help you find the nutrient content of foods
        and recipes. You can also use it to track and analyze your
        nutrient intake.</para>

    <para>Pantry is a true command-line oriented program. There are
        no menus or prompts. Of course this is clearly different
        from Web-based or GUI programs, but it also differs from
        programs that run in a text console but are menu-driven
        (such programs have been called <ulink
            url="http://en.wikipedia.org/wiki/Text_user_interface">text
            user interface</ulink> programs).</para>

    <para>Pantry may or may not be what you are looking for, so here
        is a rundown of the advantages and disadvantages of this
        program.</para>

    <section id='pantry-advantages'>
        <title>Pantry&apos;s advantages</title>

        <para> Pantry&apos;s true command-line interface gives it
            many advantages. Because Pantry works from your shell
            prompt, you can easily combine it with other
            text-processing tools. You can also easily write scripts
            incorporating Pantry, in ways that even I cannot
            anticipate. This is the strength of the Unix
            &quot;toolbox&quot; way of using a computer. </para>
            
        <para>In addition, nothing beats the speed of a command-line
            program for something you use frequently and are
            familiar with. If you are using a nutrient-analysis
            program to track your daily food intake, you will
            appreciate how quickly you can use Pantry for this
            purpose. Indeed, I developed Pantry due to my
            frustration with current tools because it was very
            tedious to use them to quickly tally a day&apos;s food
            intake. </para>

        <para>Because Pantry runs from a text console, you can
            easily set it up on one computer that has an SSH server
            running. You may then access your nutrient data from any
            computer that has an SSH client. Though Web-based
            nutrition-tracking services also offer the ability to
            access your data from any Internet-connected computer,
            Pantry is more private than Web-based services.</para>

    </section> <!-- pantry-advantages -->

    <section id='pantry-disadvantages'>
        <title>Pantry's disadvantages</title>

        <para> The biggest disadvantage of using Pantry is the same
            as its biggest advantage: its command-line interface.
            Graphical user interface programs attempt to be
            self-documenting: just sit down, click on some buttons,
            and hopefully you can figure things out. With Pantry, on
            the other hand, you will absolutely have to read this
            manual to figure out how it works, and you will need
            some practice before you are comfortable with Pantry. In
            this way, Pantry resembles other command-line oriented
            Unix programs. As with other Unix programs, once you
            learn Pantry, you will love its speed and
            efficiency--but you will have to spend some time
            learning. </para>

        <para> Similarly, because of its command-line interface, you
            will find that you are most efficient with Pantry if you
            know your way around a Unix shell prompt. For example,
            you will find that you can use Pantry more quickly if
            you know how to use your shell&apos;s features to
            manipulate your command history. Such knowledge is
            useful for any Unix command-line program, not just
            Pantry; however, building up this knowledge takes some
            time. </para>

        <para> Pantry has no tools to graphically visualize your
            food intake. I might eventually add such features using
            <ulink url='http://www.gnuplot.info/'>Gnuplot</ulink> or
            something similar.</para>

    </section> <!-- pantry-disadvantages -->

    <section id='alternatives'>
        <title>Alternatives</title>

        <para> I know I like to check out many possible programs
            before settling on one to learn to use--and I always
            like trying new programs too. Here are some possible
            alternatives to Pantry that you might take a look at:
        </para>

        <variablelist>
            <varlistentry>
                <term>NUT</term>

                <listitem>

                    <para> This is probably the leading nutrient
                        analysis program for Unix. It has a
                        text user interface and is very mature. <ulink
                            url="http://nut.sourceforge.net">NUT
                            website</ulink>. </para>

                </listitem>
            </varlistentry>

            <varlistentry>
                <term>Crosstrainer</term>

                <listitem>

                    <para> The best GUI program for nutrient
                        analysis that I have ever seen. It does more
                        than nutrient analysis, too--for example it
                        can track your exercise too. (Pantry will
                        never do anything other than nutrients.)
                        Crosstrainer only runs on Windows though,
                        and I have not used Windows in quite awhile.
                        Crosstrainer is also somewhat expensive.
                        <ulink
                            url="http://www.crosstrainer.ca/">Crosstrainer
                            website</ulink>.</para>
                </listitem>
            </varlistentry>
            <varlistentry>
                <term>nutritiondata.com</term>

                <listitem>

                    <para> This website has great tools, and neat
                        graphical features. Using it as a food diary
                        is somewhat cumbersome, however. <ulink
                            url='http://www.nutritiondata.com'>nutritiondata.com
                            website</ulink>. </para>
                </listitem>
            </varlistentry>

            <varlistentry>
                <term>Fitday</term>

                <listitem>

                    <para> This is the best food diary website that
                        I have found. <ulink
                            url='http://www.fitday.com'>Fitday
                            website</ulink>. </para>
                </listitem>
            </varlistentry>
        </variablelist>
    </section> <!-- alternatives -->

    <section id="internet">
        <title>Pantry on the Internet</title>

        <para>Visit the Pantry home page at <ulink
                url='http://www.smileystation.com/pantry' />.
            I post new versions there. I also update the Pantry
            Freshmeat listing at <ulink
                url='http://www.freshmeat.net/projects/pantry' />
            when I release new versions. Freshmeat has subscription
            services that will notify you when there is a new
            release.</para>

        <para>Pantry's source code is tracked with Git; you can
            clone the repository from <ulink
                url="http://github.com/massysett/pantry/tree/master">Github</ulink>.</para>

    </section> <!-- internet -->

</preface> <!-- about_pantry -->

<preface id="about_the_documentation">
    <title>About the documentation</title>

    <para>Right now you are reading the Pantry User Guide. This is a
        narrative document to teach you step by step how to use
        Pantry.  I hope you'll read it from beginning to end. In the
        PDF version, some of the examples run off the right side of
        the page. If you're curious about what you're missing
        (typically very little of substance) just look at the HTML
        version.</para>

    <para>Also, like any good<footnote>

            <para>I don't mean to presume that Pantry is a good
                program, but I have tried to imitate the best where
                I can.</para>

        </footnote>
        
        Unix program, Pantry has manual pages.
        They are available by invoking "man pantry" or "man pantryd"
        at the command prompt. The manual pages are not intended to
        teach you how to use Pantry. Instead, they serve as
        reference guides if you wish to jog your memory about how a
        particular feature works. You will also find the manual
        pages at the end of this User Guide.</para>

</preface> <!-- about_the_documentation -->

<preface id="installation">
    <title>Installation</title>

    <para>Pantry is written in <ulink
            url="http://en.wikipedia.org/wiki/C_plus_plus">C++</ulink>
        and distributed using the <ulink
            url="http://en.wikipedia.org/wiki/GNU_build_system">GNU
            Autotools</ulink>. If you know what that previous
        sentence means, then you don't need to read the rest of this
        section--install Pantry the usual way.</para>

    <para>If on the other hand you have never compiled software,
        never fear. Sometimes compiling software from source code
        can be tricky, but Pantry is quite easy to compile and
        install. This section will lead you through the process step
        by step.</para>

    <para>Pantry should compile and run perfectly on any recent
        Unix-like operating system. This includes any Linux
        system, the BSDs, Mac OS X, and any of the proprietary
        Unices. It might also compile and run in Cygwin; I am
        unfamiliar with Cygwin so I can't offer any help there.
        Pantry will not compile or run in Microsoft Windows, and
        I doubt this will ever change.</para>

    <section id="install_prerequisites">
        <title>Install everything you will need to compile
            Pantry</title>

        <para>You'll need to have the following software installed
            before you attempt to compile Pantry. All this software
            is quite common and will be readily available on any
            Unix system. On a Linux system, use your distribution's
            package management system to install this software, if
            it is not installed already.</para>

        <variablelist>
            <varlistentry>

                <term><command>make</command></term>

                <listitem>

                    <para><command>make</command> invokes the compiler, and it also
                        installs the compiled binaries (and other
                        files) in their proper locations. On Linux
                        this package is typically named
                        <package>make</package>.</para>

                </listitem>
            </varlistentry>

            <varlistentry>

                <term>The standard C library</term>

                <listitem>

                    <para>The standard C library contains a variety
                        of essential routines that Pantry uses for
                        file operations and interprocess
                        communications.  I can guarantee that the
                        standard C library is already installed on
                        your system, as no Unix system can work
                        without one.  However, on many Linux
                        distributions you will need to install the
                        additional "development" files. These files
                        are necessary if you wish to compile
                        software from source. Look for a package
                        named <package>libc6</package>-dev or
                        <package>glibc-devel</package> or something
                        similar. Most other Unix systems will
                        already have these additional files
                        installed.</para>

                </listitem>
            </varlistentry>

            <varlistentry>

                <term>A C++ compiler</term>

                <listitem>

                    <para> Pantry is written in C++ so you will need
                        a C++ compiler. Pantry uses only standard
                        features of the C++ language, so any recent
                        C++ compiler will work. On Linux, install
                        the GNU C++ compiler. Look for a package
                        named <package>g++</package>,
                        <package>gcc-g++</package>, or something
                        similar.</para>

                </listitem>
            </varlistentry>

            <varlistentry>

                <term>C++ standard library</term>

                <listitem>

                    <para>All C++ programs require the standard C++
                        library. Though the standard C++ library
                        likely is already installed on your system,
                        you may need to install the additional
                        "development" files, especially if you are
                        on Linux. Look for a package named
                        <package>libstdc++-devel</package>,
                        <package>libstdc++-dev</package>, or
                        something similar.</para>

                </listitem>
            </varlistentry>

        </variablelist>

    </section> <!-- install_prerequisites -->

    <section id="compile">
        <title>Compiling and installing</title>

        <para>Now that you've installed all the prerequisites,
            compiling and installing Pantry is simple: </para>

        <orderedlist>

            <listitem><para> In your normal user account, unpack the
                    tarball with <userinput>bunzip2 &lt; pantry-pb_version.tar.bz2 | tar x
                        </userinput></para></listitem>

            <listitem><para>Change to the newly created directory
                    with <userinput>cd
                        pantry-pb_version</userinput>.</para></listitem>

            <listitem><para>Run
                    <userinput>./configure</userinput>.</para></listitem>

            <listitem><para>Run
                    <userinput>make</userinput>.</para></listitem>

            <listitem><para>Become the root user by issuing
                    <userinput>su</userinput> or <userinput>sudo
                        -i</userinput>.</para></listitem>

            <listitem><para>Install Pantry with <userinput>make
                        install</userinput>.</para></listitem>

        </orderedlist>

        <para>If you are curious about what the commands listed
            above are doing, consult one of these tutorials about
            how to install software from source code:</para>

        <itemizedlist>

            <listitem><para><ulink
                        url="http://www.tuxfiles.org/linuxhelp/softinstall.html">Tuxfiles</ulink></para></listitem>

            <listitem><para><ulink
                        url="http://liquidweather.net/howto/index.php?id=82">Linux
                        Howtos</ulink></para></listitem>

        </itemizedlist>

    </section> <!-- configuring -->

</preface> <!-- installation -->

<preface id="help">
    <title>Getting help and reporting bugs</title>

    <para> The best place to start when you're learning Pantry is
        this user guide, which was written to teach you everything
        you need to know. The manual pages, pantry(1) and pantryd(1)
        were not intended to teach you how to use Pantry; they're
        better for jogging your memory on how to use this feature or
        that. </para>

    <para> If you're having trouble installing or using Pantry, send
        me an email at <ulink
            url="mailto:omari@smileystation.com">omari@smileystation.com</ulink>.
        Also, please send me an email if you have any suggestions
        for improvement or have any bugs to report.</para>

</preface>

<chapter id="pantry_paradigm">
    <title>The Pantry Paradigm</title>

    <para> Every software package comes with a set of terminology
        and ideas that you need to learn in order to use the
        software most effectively. For example, emacs users are
        familiar with buffers, regions, and the kill ring. vi users
        know the difference between normal mode and insert mode. Web
        browser users know about URLs (or, at least, addresses) and
        links. Pantry is no different, as it comes with its own set
        of terminology and its own paradigm, as you will learn about
        in this chapter. </para>

    <section id="client_server">
        <title>A client-server model</title>

        <para> Pantry is designed to work entirely from the command
            line. This gives you full access to the power of your
            shell as you work with Pantry. However, Pantry needs to
            deal with lots of data. It would take too long to load
            all this data into memory every time you execute a
            Pantry command.</para>

        <para> The solution is a client-server model. When you use
            Pantry, you'll start a server which runs in the
            background. This server will hold all the data you're
            working with. To interact with the server from the
            command line, you'll use a client program. When you're
            done with the server, you can shut it down--or you can
            just leave it running. It's up to you. </para>

        <para> Pantry comes with two binary programs, with<command>
                pantryd</command> being the server and
            <command>pantry</command> being the client. Generally
            you will only run one server at a time. The server and
            client communicate with each other using a <ulink
                url="http://en.wikipedia.org/wiki/Unix_domain_sockets">UNIX
                domain socket</ulink>, which is a common means of
            interprocess communication on Unix. By default, this
            socket is a file at
            <filename>$HOME/.pantrySocket</filename>. If you want to
            use a different location for your socket file, you can
            do so by setting the environment variable PANTRY_SOCKET
            before you start <command>pantryd</command>, and you
            will also need to be sure the PANTRY_SOCKET variable is
            set each time you run <command>pantry</command>. Specify
            the entire path to the socket, including the filename
            itself (it need not be named
            <filename>.pantrySocket</filename>). By using the
            PANTRY_SOCKET variable, you can run more than one
            <command>pantryd</command> server
            simultaneously.<footnote>
            
                <para>You might need to use PANTRY_SOCKET if the
                    default socket location does not work for you
                    because, for example, you don't have permission
                    to create files in your home directory or if
                    your home directory is on a filesystem that does
                    not allow creation of sockets. Otherwise, I
                    can't imagine why most folks would want to run
                    more than one server simultaneously, though this
                    feature does come in handy when I am testing new
                    versions of Pantry and preparing them for
                    release.</para>
            </footnote>
            
            </para>

    </section> <!-- client_server -->

    <section id="foods">
        <title>Foods</title>

        <para>You will work with Pantry by manipulating what we will
        call foods. Each food in Pantry has various pieces of data
        associated with it, called traits, nutrients, and available
    units.</para>

        <section id="traits">
            <title>Traits</title>

            <para>A food's traits is a set of twelve strings. Each
                of these strings indicates something interesting
                about the food. For instance, four of these traits
                are <varname>name</varname>,
                <varname>date</varname>,
                <varname>quantity</varname>, and
                <varname>unit</varname>. For a particular food,
                these might be equal to <literal>Apples, raw, with
                    skin</literal>, <literal>Wednesday</literal> (to
                indicate the date that you ate it)
                <literal>2</literal> and <literal>large (3-1/4"
                    dia)</literal> to indicate that you ate two
                large apples.  Of course you can change a food's
                traits.  For instance, you can rename any food
                whenever you want, and you can change its quantity
                and unit traits to indicate how much you ate (or
                just to see the nutrient breakdown for that
                particular quantity and unit.)</para>

            <variablelist>
                <title>Twelve food traits</title>

                <varlistentry>
                    <term><varname>name</varname></term>

                    <listitem>

                        <para> This is the name of the food, such as
                            <literal>Apples, raw, with
                                skin</literal>.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>group</varname></term>

                    <listitem>

                        <para>You can assign whatever you like to
                            this trait to group foods. The foods in
                            the
                            <filename>starter_database</filename>
                            file already have group traits
                            corresponding to the food groups used by
                            USDA; for instance, <literal>Apples,
                                raw, with skin</literal> has a group
                            trait of <literal>Fruits and Fruit
                                Juices</literal>.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>quantity</varname></term>

                    <listitem>

                        <para> This is a number. You can use an
                            integer, like <literal>2</literal>; a decimal, like <literal>2.5</literal>; a
                            fraction, like <literal>1/2</literal>; or a mixed number,
                            like <literal>2 1/2</literal>.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>unit</varname></term>

                    <listitem>

                        <para> This is a string. It must be equal to
                            one of the food's available units. Every
                            food has <literal>g</literal>,
                            <literal>oz</literal>, and
                            <literal>lb</literal> as available
                            units; you can also assign additional
                            available units to a food, as we will
                            discuss later.  Later we will also see
                            how you can find out what a food's
                            available units are.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>date</varname></term>

                    <listitem>

                        <para> You can assign whatever you wish to
                            this trait to indicate when you ate a
                            food, if you wish. This does not need to
                            be formatted any particular way, so you
                            can use <literal>2008-05-18</literal>,
                            <literal>Sunday</literal>, or
                            <literal>the day before
                                yesterday</literal> if you
                            want.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>meal</varname></term>

                    <listitem>

                        <para> A string indicating what meal you ate
                            a food at, such as
                            <literal>Lunch</literal> or
                            <literal>midday snack</literal>.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>comment</varname></term>

                    <listitem>

                        <para> Any comments you may wish to add.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>order</varname></term>

                    <listitem>

                        <para> Sometimes you may want your foods to
                            be sorted in a particular order when you
                            print reports; to do that you can assign
                            appropriate values to this trait, such
                            as <literal>a</literal> for one food and
                            <literal>b</literal> for the next food.
                            As we will see later, Pantry can also
                            assign values to this trait for you if
                            you wish.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>refuse</varname></term>

                    <listitem>

                        <para> A description of the refuse of a
                            food--that is, the part you don't eat,
                            like bones or shells. For
                            <literal>Apples, raw, with
                                skin</literal>, this is
                            <literal>Core and stem</literal>.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>percent-refuse</varname></term>

                    <listitem>

                        <para> The percent of the food that is
                            refuse. As we will see later Pantry can
                            use the value of this trait to make it
                            easier for you to keep track of food
                            quantities. As with the quantity trait,
                            this can be an integer, decimal value,
                            fraction, or mixed number. For
                            <literal>Apples, raw, with
                                skin</literal>, this is
                            <literal>10</literal>, which is roughly
                            the percentage of an apple's weight that
                            is core and stem.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>yield</varname></term>

                    <listitem>

                        <para> Later you will learn how to create
                            your own recipes in Pantry. This trait
                            indicates the total yield of a recipe,
                            in grams.</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term><varname>instructions</varname></term>

                    <listitem>

                        <para> For a recipe, this may contain any
                            preparation instructions you may wish to
                            add.</para>

                    </listitem>
                </varlistentry>
            </variablelist>
        </section> <!-- traits -->

        <section id="nutrients">
            <title>Nutrients</title>

            <para>A food's nutrients is a set of pairs of strings
                and numbers. These indicate the nutrient breakdown
                of a food. For example, the food with the name trait
                <literal>Apples, raw, with skin</literal> whose
                quantity trait is <literal>1</literal> and whose
                unit trait is <literal>large (3-1/4" dia)</literal>
                has 100 nutrients total. Some of the more
                interesting ones are <literal>Calories</literal>
                which is <literal>116</literal>; <literal>Calcium,
                    mg</literal> which is 13, and <literal>Dietary
                    Fiber, g</literal> which is
                <literal>5</literal>. A food's nutrients adjust
                automatically as you change its quantity or unit
                traits.</para>
        </section>

        <section id="avail_units">
            <title>Available units</title>

            <para>A food's available units indicate various possible
                quantities of a food, and how much each given
                quantity weighs in grams. For example, the food
                whose name trait is <literal>Apples, raw, with
                    skin</literal> has ten available units total.
                Among these are <literal>large (3 1/4"
                    dia)</literal>, which is 223g, and <literal>cup
                    slices</literal>, which is 109g. Every food
                always has <literal>g</literal>,
                <literal>oz</literal>, and <literal>lb</literal> as
                available units. </para>

        </section>

    </section> <!-- foods -->

    <section id="collections_databases">
        <title>Collections and databases</title>

        <para>A collection holds foods. Every food must be in a
            collection. You can use collections to group foods in a
            way that is convenient to you--for example, by day of
            the week, or by foods you eat frequently. A database
            holds one or more collections. In Pantry you can only
            work with one database at a time, though you can work
            with more than one collection as long as they are in the
            same database. You can save databases to disk so you can
            load them again later.</para>

    </section> <!-- collections_databases -->

</chapter> <!-- pantry_paradigm -->

<chapter id="basics">
    <title>Manipulating foods</title>

    <para> Now that you know some essential Pantry terminology,
        you're ready to jump in and do something interesting. In
        this chapter you'll learn how to use Pantry to find
        nutrition information about foods.</para>

    <section id="opening_file">
        <title>Opening files and getting server status</title>

        <para> As you learned in the previous chapter, Pantry
            employs a client-server architecture. So the first thing
            you must do when working with Pantry is start a server.
            To start a server, simply type
            <userinput>pantryd</userinput> at a command
            prompt:</para>

        <example>
            <title>Starting the Pantry server</title>
            pb_verbatim({pantryd})
        </example>

        <!-- Deal with race conditions by waiting for a brief moment -->
        pb_sh({sleep .5 >/dev/null 2>&1})

        <para> This starts up a Pantry server in the background and
            returns you to your prompt. This server will keep
            running, even after you logout of the shell from which
            you started the server.<footnote>

                <para>As we will discuss later, to terminate the
                    server, run <userinput>pantry
                        --quit</userinput>.</para>

            </footnote>
            
            If you're a skeptic and you
            don't believe that you actually have a program running
            in the background, you can verify that a Pantry server
            is running by using your <command>ps</command> command. 
        </para>

        <para> Now to interact with the server you'll use the
            <command>pantry</command> command. First let's load a
            database. Pantry comes with the
            <filename>starter_database</filename> file.  It contains
            over 7,000 foods from the USDA's <ulink
                url="http://www.ars.usda.gov/Services/docs.htm?docid=8964">National
                Nutrient Database for Standard Reference</ulink>.
            You'll find this file at
            <filename>$PREFIX/share/pantry/data/starter_database</filename>,
            where $PREFIX is the prefix you used when you ran the
            configure script. (This defaults to
            <filename>/usr/local</filename>.) So to open the file
            run a command similar to this. Just make an appropriate
            substitution for the location of your
            <filename>starter_database</filename> file: </para>

        <example>
            <title>Opening a database</title>
            pb_verbatim({pantry --open data/starter_database})
        </example>

        <para> As with the previous command, you're returned to your
            prompt without a message. Pantry generally is quite
            terse--if it has nothing surprising to say, or if you
            have not asked it to say anything, then it stays quiet.
            If you're wondering if that last command really did
            anything, you can ask the server to report its status:
        </para>

        <example>
            <title>Getting server status</title>
            pb_verbatim({pantry --status})
        </example>

        <para> This shows that the database you just opened has a
            single collection, called <literal>master</literal>,
            with 7413 foods.</para>

    </section> <!-- opening_file -->

    <section id="printing">
        <title>The <literal>name</literal>, <literal>info</literal>,
            and <literal>blank</literal> reports</title>

        <para>Next let's learn how to print reports, which are
            Pantry's way of telling you what you want to know about
            foods. Most invocations of the Pantry command take the
            form <userinput>pantry [options]
                COLLECTION...</userinput> When you enter a <command>pantry</command>
            command, you will usually specify one or more
            collections as non-option arguments<footnote>

                <para>When I say non-option arguments, it's to
                    distinguish these arguments from the arguments
                    with leading single or double dashes. </para>

            </footnote>. For example, as we saw above, the
            <filename>starter_database</filename> file comes with one collection, named
            <literal>master</literal>. </para>

        <para> In order to learn exactly what foods are in the
            <literal>master</literal> collection, you can print
            reports about the foods. For example, the simplest
            report is the <literal>name</literal> report, which
            prints the name trait of every food in the buffer:
        </para>

        <example>
            <title>The <literal>name</literal> report</title>
            pb_verbatim({pantry --print name master | head})
        </example>

        <para>Thus you use the <option>--print</option> option to
            print reports. The <option>--print</option> option takes
            a single argument, which is the name of the
            report--here, <literal>name</literal>. Finally you
            specify the collection or collections that has the foods
            you're interested in--here, <literal>master</literal>.
            Pantry first copies every food from the
            <literal>master</literal> collection into the buffer. It
            then prints a name report for every one of those foods.
            That's a lot of foods--over 7,000 of them, so in the
            manual I've piped the output to <command>head</command>
            to save some space.  After your pantry command is done,
            the foods that were copied to the buffer are gone, and
            the foods in the <literal>master</literal> collection
            are unchanged.</para>

        <para>To know more than just the name of a food, use the
            <literal>info</literal> report. It prints information
            about most of a food's traits. It does not print
            information about the food's <varname>name</varname>
            trait (for that, use the <literal>name</literal> report)
            or about some of the traits that are related only to
            foods that are recipes (we'll discuss reports applicable
            to recipes later.) To save space, the
            <literal>info</literal> report does not print
            information about a trait if it is blank. You can print
            more than one report at a time simply by specifying
            multiple <option>--print</option> options.</para>

        <example>
            <title>The <literal>info</literal> report</title>
            pb_verbatim({pantry --print name --print info master | head})
        </example>

        <para>For every food in the buffer, Pantry first printed a
            <literal>name</literal> report and then printed an
            <literal>info</literal> report. As you can see, some
            whitespace would help make this more readable.  To get
            whitespace use the <literal>blank</literal> report,
            which prints a blank line: </para>

        <example>
            <title>The <literal>blank</literal> report</title>
            pb_verbatim({pantry --print name --print info \
                         --print blank master | head})
        </example>

        <para> All the reports we have seen so far are printed once
            for every food in the buffer. We'll call these reports
            food reports. On the other hand, some reports are
            printed just once for the entire buffer, no matter how
            many foods are in the buffer. We'll call these reports
            summary reports because they summarize information for
            the entire buffer. One summary report is the <literal>groups</literal>
            report, which tells you information about the group
            trait of every food in the buffer: </para>

        <example>
            <title>The <literal>groups</literal> report</title>
            pb_verbatim({pantry --print groups master})
        </example>
    </section>

    <section id="selecting">
        <title>Selecting foods with the <option>--search</option> option</title>

        <para> As you learned in the previous section, the
            information in your reports in Pantry depends on what
            foods are in the buffer, and when you specify a
            collection name as an argument to the
            <command>pantry</command> command, Pantry copies all the
            foods from that collection into the buffer. So every
            report we saw in the previous section pertained to all
            the foods in the <literal>master</literal> collection in
            the <filename>starter_database</filename> file--that's
            over 7,000 foods. Often you'll only be interested in a
            fraction of the foods in a particular collection. That's
            where the <option>--search</option> option comes in. </para>

        <para> With the <option>--search</option> option, you
            specify a particular trait, such as name, date, or
            group, and a pattern you wish to match for that
            particular trait. As we learned before, Pantry first
            copies every food from the each collection you specify
            into the buffer. However, when you specify
            <option>--search</option> options, Pantry then
            eliminates every food whose trait does not match the
            pattern you specified. An example will help: </para>

        <example>
            <title>Using <option>--search name</option></title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --print name --print info master})
        </example>

        <para> You have to quote the second argument to the <option>--search</option>
            option if, as here, it contains characters that the
            shell gives special meaning to, such as spaces. <ulink
                url="http://www.mpi-inf.mpg.de/~uwe/lehre/unixffb/quoting-guide.html">Here</ulink>
            is an excellent guide that explains why and when quoting
            is necessary.</para>

        <para> As with the <option>--print</option> option, you may
            specify multiple <option>--search</option> options in a
            single command. The effect of multiple
            <option>--search</option> options is cumulative; that
            is, a food must match all of the
            <option>--search</option> options specified, or Pantry
            will remove it from the buffer. </para>

        <example>
            <title>Using multiple <option>--search</option> options</title>
            pb_verbatim({pantry --search name Apples --print name master})
            pb_verbatim({pantry --search name Apples \
                         --search name skin --print name master})
        </example>

        <para> You can search using any trait you wish, not just the
            name trait. For example, you can show all foods with the
            word <literal>Fruit</literal> in their group trait:</para>

        <example>
            <title>Using the <varname>group</varname> trait in a search</title>
            pb_verbatim({pantry --search group Fruit --print name \
                         --print info --print blank master | head})
        </example>

        <para> As with many things Unix, by default the <option>--search</option>
            option is case sensitive. To make it case insensitive,
            use the <option>--ignore-case</option> option. This makes the pattern to
            every <option>--search</option> option case insensitive. </para>

        <example>
            <title>The <option>--ignore-case</option> option</title>
            pb_verbatim({pantry --search name papaya \
                         --print name master})
            pb_verbatim({pantry --ignore-case \
                         --search name papaya \
                         --print name master})
        </example>

        <para> Also, by default the search patterns are <ulink
                url="http://www.regular-expressions.info">regular
                expressions</ulink>.<footnote>

                <para>Pantry uses the regular expression routines
                    that come with the standard UNIX C library.
                    Pantry uses "extended" regular expressions;
                    typically they are similar to what your egrep
                    command uses. These regular expressions are less
                    versatile than those Perl uses, but they are
                    usually good enough and they are available on
                    any Unix system. </para>

            </footnote>

            If a regular expression matches any part of the trait,
            then the food matches. This can have mildly unexpected
            results.  Sometimes you may wish to use <ulink
                url="http://www.regular-expressions.info/anchors.html">anchors</ulink>.
            In addition, there is an <option>--exact-match</option>
            option which turns off regular expressions. When you use
            exact match, all search patterns must exactly match the
            search patterns given.  </para>

        <example>
            <title>Patterns, anchors, and <option>--exact-match</option></title>
            pb_verbatim({pantry --search name "Apples, raw, without skin" \
                         --print name master})
            pb_verbatim({pantry --search name "Apples, raw, without skin$" \
                         --print name master})
            pb_verbatim({pantry --exact-match \
                         --search name "Apples, raw, without skin" \
                         --print name master})
        </example>
    </section>

    <section id="changing_foods">
        <title>The <literal>units</literal> report, and changing foods</title>

        <para>Now you know how to search for foods and print
            information about them. This is often useful all by
            itself, but often you will want to change foods. To
            change a trait, just use the <option>--change</option>
            option:</para>

        <example>
            <title>Changing traits</title>
            pb_verbatim({pantry --ignore-case --search name papaya \
                         --change group "Tropical Fruits" \
                         --print name --print info --print blank \
                         master})
        </example>

        <para> As you already know, when you execute a pantry
            command, Pantry first copies all foods from every
            collection you specify into a buffer. Pantry then
            removes from the buffer all foods that do not match any
            <option>--search</option> optionis you specified. Next
            is where the <option>--change</option> option comes in.
            Pantry changes every food in the buffer using any
            <option>--change</option> options you have specified.
            After that, Pantry prints any reports you have requested
            with the <option>--print</option> option. </para>

        <para> Remember that Pantry first copies foods from the
            collections into the buffer, so when you use the change
            option, the original foods that are in the collection
            are not changed. In the last example we changed the
            group trait of some foods that have
            <literal>papaya</literal> in their name trait, but as
            this shows, this change did not affect the foods in the
            <literal>master</literal> collection: </para>

        <example>
            <title>Changes only affect foods in the buffer</title>
            pb_verbatim({pantry --ignore-case --search name papaya \
                         --print name --print info --print blank \
                         master})
        </example>

        <para> To make changes permanent, you can use the
            <option>--add</option>, <option>--edit</option>, and
            <option>--delete</option> options, which we will talk
            about later.</para>

        <para> As we discussed earlier, every food in Pantry has
            twelve traits. Of these twelve, you can assign whatever
            text you want to eight: <varname>name</varname>,
            <varname>group</varname>, <varname>date</varname>,
            <varname>meal</varname>, <varname>comment</varname>,
            <varname>order</varname>, and <varname>refuse</varname>.
            Of course you might be less confused if you, say,
            refrain from using the refuse trait to store information
            about when you ate a food, but that is up to you. You
            are not constrained to using a particular format for the
            date trait; later on, when we discuss the <option>--key</option> option,
            we'll learn of some considerations you might want to
            take into account when assigning information to this
            trait. </para>

        <para> The <varname>quantity</varname> trait is a number.
            When you assign values to it using the
            <option>--change</option> option, you must use a value
            that evaluates to a number. You can use whole numbers
            (such as <literal>2</literal>), decimals (such as <literal>2.5</literal>), fractions (such as
            <literal>2/3</literal>) or mixed numbers (such as <literal>1 2/3</literal>). If you try to use
            anything else for the quantity trait, Pantry will give
            you an error message and quit. </para>

        <example>
            <title>Changing the <varname>quantity</varname> trait</title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --change quantity "2 1/2" \
                         --print name --print info master})
        </example>

        <para> Entering <literal>0</literal> for a food's quantity trait does not
            delete a food; to do that, use the
            <option>--delete</option> option which
            we will talk about later. </para>

        <para> The <varname>percent-refuse</varname> trait is
            similar to the <varname>quantity</varname> trait in that it is also a
            number. However, the <varname>percent-refuse</varname> trait has one
            additional requirement: it must be between
            <literal>0</literal> and <literal>100</literal>,
            inclusive, because a food can't have less than zero
            percent refuse or more than 100 percent refuse. </para>

        <para> As we discussed much earlier, each food in Pantry may
            have a number of available units. Knowing what these are
            will come in handy later when you wish to change the
            units of a food, but for now let's just see what a
            <literal>units</literal> report looks like. </para>

        <example>
            <title>Units report</title>
            pb_verbatim({pantry --ignore-case --search name papaya \
                         --print name --print units --print blank \
                         master})
        </example>

        <para> Every food has <literal>g</literal>,
            <literal>oz</literal>, and <literal>lb</literal>
            available as units, so the units report does not show
            these to save some space.  </para>

        <para> The <literal>unit</literal> trait must be set to be
            equal to one of the food's available units. When you are
            changing a food's unit, the second argument to the
            <option>--change</option> option is a regular expression that must match
            exactly one of the food's available units.  If the
            regular expression does not match exactly one of the
            food's available units, Pantry will give you an error
            message and quit.</para>

        <example>
            <title>Changing the <varname>unit</varname> trait</title>
            pb_verbatim({pantry --search name "Papayas, raw" \
                         --change quantity 1 \
                         --change unit large \
                         --print name --print info master})
        </example>

        <para> As always with the <option>--change</option> options,
            using <option>--change</option> unit will change every
            food in the buffer so that its unit matches the pattern
            you give. For example, take the following output from a
            <literal>units</literal> report: </para>

        <example>
            <title>Papaya units reports</title>
            pb_verbatim({pantry --ignore-case --search name papaya \
                         --print name --print units --print blank \
                         master})
        </example>

        <para> Remember that every food has <literal>g</literal>,
            <literal>oz</literal>, and <literal>lb</literal> as
            available units, so I could have appended
            <userinput>--change unit "lb"</userinput> to the previous
            command. However, had I appended <userinput>--change unit small</userinput> to
            the previous command, <command>pantry</command> would have given me an
            error message and quit because only one of the foods in
            the buffer had an available unit that matched that
            pattern. </para>

        <para> Let's say I want to change a papaya's unit to <literal>g</literal> (for
            grams). What if I wanted to run <userinput>pantry --search name
            "Papayas, raw" --change unit g master</userinput>? That would give
            me an error message because <literal>g</literal> matches both <literal>g</literal> and <literal>large
            (5-3/4" long x 3-1/4" dia)</literal>. One solution to this is to
            use anchors by specifying <userinput>--change unit '^g$'</userinput>
            instead.<footnote>

                <para> I do this with some frequency, so to make it
                    a little easier to type I have <userinput>alias -g
                    G='\^g\$'</userinput> in a file that defines Pantry
                    shell functions, parameters, and aliases for me.
                    This will only work in <command>zsh</command>. </para>

            </footnote> Another is to use the
            <option>--exact-match</option> option.  Because the
            second argument to the <option>--change unit</option>
            option is a regular expression, it respects the
            <option>--exact-match</option> and
            <option>--ignore-case</option> options just as the
            <option>--search</option> option does. Thus, <userinput>
                pantry --exact-match --search name "Papayas, raw"
                --change unit g master </userinput> works perfectly.
        </para>

    </section> <!-- available_units -->

    <section id="permanent">
        <title>Making changes permanent</title>

        <para> As we've been pointing out, when you make changes to
            foods using the <option>--change</option> option, these changes are not
            permanent. This is because those changes are to foods
            that are in the buffer, which is Pantry's temporary
            holding place for foods. You get a new buffer every time
            you run a pantry command. </para>

        <para> There are three ways to make your changes permanent.
            The one you'll use the most is the <option>--add</option> option.  This
            takes the entire buffer and adds its contents to the
            specified collection:</para>

        <example>
            <title>Adding foods to a collection</title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --change quantity 2 \
                         --change unit medium \
                         --change date 2008-06-22 \
                         --change meal Lunch \
                         --add diary \
                         master})
            pb_verbatim({pantry --print name --print info diary})
        </example>

        <para> The <option>--add</option> option is the easiest way
            to keep a food diary. You simply search for foods in the
            <literal>master</literal> collection, change their
            traits as appropriate (such as their
            <varname>quantity</varname>, <varname>date</varname>,
            and <varname>meal</varname> traits) and then add them to
            another collection. I typically add all my diary foods
            to one collection, <literal>diary</literal>, but you can
            use multiple collections for this purpose--such as one
            collection for each day, week, or whatever. You can even
            add a food to more than one collection at a time; just
            use multiple <option>--add</option> options, one for
            each collection.</para>

        <para> Once you have added a food to a collection with
            <option>--add,</option> that food is independent of the collection it
            came from. That is, in the previous example, if you then
            make changes to the apple you just added to
            diary, this will not affect the food in the
            <literal>master</literal> collection. </para>

        <para> Thus the <option>--add</option> option works by copying foods from the
            buffer into a collection. Sometimes though you will want
            to change a food that is already in a collection,
            without copying it. For example, let's say that in the
            previous example I made a mistake. I really wanted to
            indicate that I ate one medium apple, not two. The
            <option>--edit</option> option will help you here. </para>

        <example>
            <title>Using the <option>--edit</option> option</title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --search date 2008-06-22 \
                         --search meal Lunch \
                         --change quantity 1 \
                         --edit \
                         diary})
            pb_verbatim({pantry --search date 2008-06-22 \
                         --print name --print info --print blank \
                         diary})
        </example>

        <para> With the <option>--edit</option> option, Pantry copies foods from the
            source collections and makes the changes indicated using
            the --change option, as it always does. However, when
            you use <option>--edit,</option> Pantry will make changes to the foods
            that are inside the original collections, as well as
            making changes to the foods that are in the buffer.
        </para>

        <para> Or, let's say that I decided that I didn't really eat
            an apple after all. Then I can use the <option>--delete</option> option:
        </para>

        <example>
            <title>Using the <option>--delete</option> option</title>
            pb_verbatim({pantry --search date 2008-06-22 \
                         --search name Apples \
                         --print name \
                         --delete diary})
            pb_verbatim({pantry --status})
        </example>

        <para> As you can see, the diary collection now has no foods
            because you deleted the single food that was in the
            collection. </para>

        <para> With the <option>--delete,</option> option, after
            copying foods into the buffer and making any changes you
            specify, Pantry then deletes the foods from the original
            collections. The foods are still present in the buffer,
            which is why you can still <option>--print</option>
            them. </para>

    </section> <!-- adding -->

    <section id="nut_reports">
        <title> Reports about nutrients</title>

        <para> There are two reports to tell you about the nutrient
            content of foods. First we will discuss the <literal>goals</literal>
            report. It allows you to specify the nutrients you wish
            to see in a report:</para>
            
        <example>
            <title>The <literal>goals</literal> report</title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --print name --print info --print goals \
                         --goal Calories 2600 \
                         --goal "Total Fat, g" 43 \
                         --goal "Protein, g" 162 \
                         --goal "Total Carbohydrate, g" 390 \
                         --goal "Dietary Fiber, g" 0 \
                         master})
        </example>

        <para>As the example illustrates, you specify the nutrients
            you wish to see in the goals report by using multiple
            <option>--goal</option> options, and the nutrients are shown in the order
            in which you asked for them with the <option>--goal</option> options. The
            first argument to each <option>--goal</option> option specifies the
            nutrient you wish to see. Unlike many other things in
            Pantry, this argument is not a regular
            expression--instead, for a nutrient to be printed in the
            goals report, its name must exactly match one of the
            nutrients specified with a <option>--goal</option> option. The <option>--goal</option>
            option is always case sensitive, even if you have
            specified the <option>--ignore-case</option> option. </para>

        <para> The second argument to each <option>--goal</option> option is a goal.
            For instance, here I have specified that it is my goal
            to eat 2600 calories, 43 grams of fat, and so on. These
            goals can be per day, per month, per meal...whatever you
            want. If you don't have a goal for a particular
            nutrient, just specify <literal>0</literal>. (You do, however, have to
            specify a goal, even if it is zero.) </para>

        <para> With that, you can probably figure out what all the
            columns in the goals report mean. The first is simply
            the name of the nutrient. The second is the amount of
            the nutrient present. The third column is the ratio of
            the second column to the goal you specified, expressed
            as a percentage.</para>
            
        <para>The fourth column shows this nutrient's percentage of
            the total amount of that nutrient in the buffer. This
            makes more sense with an example. Suppose I am a
            fruititarian: </para>

        <example>
            <title>My fruititarian foods</title>
            pb_verbatim({pantry --search name 'Apples, raw, with skin' \
                         --change quantity 3 \
                         --change unit large \
                         --change date 2008-06-12 \
                         --change meal Breakfast \
                         --add diary \
                         master})
            pb_verbatim({pantry --search name 'Bananas, raw' \
                         --change quantity 1 \
                         --change unit medium \
                         --change date 2008-06-12 \
                         --change meal Lunch \
                         --add diary \
                         master})
            pb_verbatim({pantry --search name 'Papayas, raw' \
                         --change quantity 2 \
                         --change unit large \
                         --change date 2008-06-12 \
                         --change meal Dinner \
                         --add diary \
                         master})
        </example>

        <example>
            <title>My fruititarian report</title>
            pb_verbatim({pantry --search date 2008-06-12 \
                         --print name --print info --print goals \
                         --print blank \
                         --goal Calories 2600 \
                         --goal "Total Fat, g" 43 \
                         --goal "Protein, g" 162 \
                         --goal "Total Carbohydrate, g" 390 \
                         --goal "Dietary Fiber, g" 0 \
                         diary})
        </example>

        <para> The <literal>goals</literal> report tells you only about the nutrients
            that you ask for. To know about all the nutrients in a
            food, use the <literal>nuts</literal> report instead.  Because the people
            at USDA are so industrious, the foods in the
            <filename>starter_database</filename> file have lots of nutrients. Let's see
            some of them for the apple. Of course when you run this
            on your computer you can omit the <userinput>| head</userinput>, but I did that
            here to save some space in the manual. The columns in
            the <literal>nuts</literal> report mean the same as the corresponding
            columns in the goals report; however, unlike the <literal>goals</literal>
            report, you do not need to enter a goal for a nutrient
            in order for the nutrient to be shown in the nuts
            report; instead, all of a food's nutrients are
            shown.</para>

        <example>
            <title>The <literal>nuts</literal> report</title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --print name --print nuts master | head})
        </example>

        <para>The <option>--goals</option> and <option>--nuts</option> report tell you about each food
            in the buffer. To get information about the total
            nutrient content of a buffer, use the <literal>Goals</literal> and <literal>Nuts</literal>
            summary reports. </para>

        <example>
            <title>Using the <literal>Goals</literal> and <literal>Nuts</literal> reports</title>
            pb_verbatim({pantry --search date 2008-06-12 \
                         --print Goals \
                         --goal Calories 2600 \
                         --goal "Total Fat, g" 43 \
                         --goal "Protein, g" 162 \
                         --goal "Total Carbohydrate, g" 390 \
                         --goal "Dietary Fiber, g" 0 \
                         diary})
            pb_verbatim({pantry --search date 2008-06-12 \
                         --print Nuts diary | head})
        </example>
    </section> <!-- nutrient_reports -->

    <section id="sorting">
        <title>Sorting reports, and using <option>--auto-order</option></title>

        <para> For all practical purposes, Pantry stores foods in
            collections in no particular order. Thus, when you use
            the <option>--print</option> option to print reports, you don't know what
            order your foods will come out in. That can make it hard
            to find the information you're looking for. </para>

        <para> That's why Pantry has options so it will sort foods
            in an order you specify. You sort foods by adding keys.
            A key is a particular trait that you wish to use to
            sort foods. For example: </para>

        <example>
            <title>A basic sorting example</title>
            pb_verbatim({pantry --key name \
                         --print name --print info --print blank \
                         diary})
        </example>

        <para> If you want Pantry to sort in descending rather than
            ascending order,<footnote>

                <para>Pantry sorts in what has sometimes been called
                    ASCIIbetical order. Pantry knows nothing about
                    multibyte characters. See <xref
                        linkend="limitations" />.</para>

            </footnote>
            
            use a capital letter to specify the
            name of the trait: </para>

        <example>
            <title>Sorting in descending order</title>
            pb_verbatim({pantry --key Name \
                         --print name --print info --print blank \
                         diary})
        </example>

        <para> You can also specify more than one
            <option>--key</option>. Then Pantry will first sort
            foods using the first key, then by the second key, etc.
            For instance, here Pantry will sort foods first by their
            <varname>date</varname> traits. Foods with identical
            <varname>date</varname> traits will be sorted by
            <varname>name</varname>. </para>

        <example>
            <title>Specifying more than one <option>--key</option></title>
            pb_verbatim({pantry --search name \
                         "Snacks, popcorn, microwave, low fat" \
                         --change quantity 2 \
                         --change unit oz \
                         --change date 2008-06-20 \
                         --change meal Lunch \
                         --add diary master})
            pb_verbatim({pantry --search name \
                         "Carbonated beverage, cola, contains caffeine" \
                         --change quantity 1 \
                         --change unit can \
                         --change date 2008-06-20 \
                         --change meal Lunch \
                         --add diary master})
            pb_verbatim({pantry --key date --key name \
                         --print name --print info --print blank \
                         diary})
        </example>

        <para> You might want to sort your foods in a particular
            order rather than alphabetical order. For instance, you
            might want to see foods sorted by meal. This would yield
            <literal>Breakfast</literal>, <literal>Dinner</literal>, <literal>Lunch</literal> if sorted alphabetically. To
            fix this, use the <option>--list</option> option. This allows you to list
            values for a particular trait. Foods will then be sorted
            in the order that you specified. (All foods having a
            trait whose value is not listed with the <option>--list</option> option
            will be sorted alphabetically, after foods whose trait
            values were specified with <option>--list.)</option> </para>

        <example>
            <title>Using the <option>--list</option> option to sort foods</title>
            pb_verbatim({pantry --search date 2008-06-12 \
                         --list meal Breakfast \
                         --list meal Lunch \
                         --list meal Dinner \
                         --key meal \
                         --print name --print info \
                         --print blank diary })
        </example>

        <para> The <option>--list</option> option is always case sensitive; it is not
            affected by the <option>--ignore-case</option> option. The second
            argument to the <option>--list</option> option is just a plain string, not
            a regular expression pattern.</para>

        <para> You may find that you want to add foods to a
            collection in a particular order and then see them
            reported in that order. Because Pantry stores foods in a
            manner that is for all practical purposes unordered,
            just adding foods to a collection in a particular order
            does not ensure they will be shown in that order in
            reports. Instead, that's what the <option>--auto-order</option> option is
            for. If you use it when adding a food to a collection,
            Pantry will automatically scan the collection for foods
            with identical <varname>date</varname> and <varname>meal</varname> traits. Pantry will then
            set the order trait of the food that is added to the
            collection so that the new food's <varname>order</varname> trait will come
            after all the other foods with identical <varname>date</varname> and <varname>meal</varname>
            traits. Then you can sort foods using the <varname>order</varname> trait to
            see them in the order in which you added them.
        </para>

        <para> Phew! That's a long explanation. An example will
            help: </para>

        <example>
            <title>Using the <option>--auto-order</option> option</title>
            pb_verbatim({pantry --search name "McDONALD'S, French Fries" \
                         --change quantity 1 \
                         --change unit large \
                         --change date 2008-06-21 \
                         --change meal Lunch \
                         --add diary --auto-order \
                         master})
            pb_verbatim({pantry --search name "McDONALD'S, Double Cheeseburger" \
                         --change quantity 1 \
                         --change unit item \
                         --change date 2008-06-21 \
                         --change meal Lunch \
                         --add diary --auto-order \
                         master})
            pb_verbatim({pantry --search date 2008-06-21 \
                         --search meal Lunch \
                         --key order \
                         --print name --print info --print blank \
                         diary})
        </example>

        <para> <option>--auto-order</option> does not require that you change either
            the <varname>date</varname> or <varname>meal</varname> traits of foods; it will work fine if
            those traits are left blank (all the foods in the
            <filename>starter_database</filename> file have blank date and meal traits.)
        </para>
    </section>

    <section id="approximate">
        <title>Approximations with the <option>--refuse</option> and <option>--by-nut</option>
            options</title>

        <para> "There's good, and then there's good enough," I like
            to say. Pantry has two options that can help you when
            you are looking for approximations.</para>

        <para> First the <option>--refuse</option> option. So far we have paid little
            attention to the <varname>refuse</varname> trait, which specifies the
            typical percentage of a food that is inedible. If you
            use this option, Pantry will reduce the quanitity of
            each food in the buffer by each food's percent-refuse
            trait. For example, apples range in size from tiny
            (about 6 oz, say) to enormous (over a pound!) If I am
            eating an apple, there are various ways I can use Pantry
            to find out the apple's nutrient content. First, I can
            look at it, guess its size, and then use the units
            report to find the appropriate available unit for
            <literal>Apples, raw, with skin</literal>. This requires that I make a good
            guess, but I am quite bad at guessing these things.
        </para>

        <para> I could weigh the apple. The problem here is that
            the foods in the <filename>starter_database</filename> file have nutrient
            amounts for a given edible portion of food. These
            amounts don't include the core, stem, and seeds of the
            apple. So for the best accuracy I would have to cut up
            the apple and remove the core, stem, and seeds before
            weighing it. </para>

        <para> Another alternative is the <option>--refuse</option> option. This way
            I can weigh the apple whole. Pantry will then deduct the
            appropriate amount from the quantity. </para>

        <example>
            <title>Using the <option>--refuse</option> option</title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --refuse \
                         --change quantity 395 \
                         --change unit '^g$' \
                         --print name --print info master})
        </example>

        <para> Of course you can tack on options like <option>--print goals</option>
            and <option>--goal</option> in order to find more useful information
            about the apple. </para>

        <para> There's no reason to use the <option>--refuse</option> option if you
            are using an available unit other than <literal>g</literal>, <literal>oz</literal>, or <literal>lb</literal>. In
            the <filename>starter_database</filename> file, all available units (other
            than <literal>g</literal>, <literal>oz</literal>, and <literal>lb</literal>) already represent the edible portion
            of a food. For instance, the <literal>large (3-1/4" dia)</literal>
            available unit for Apples, raw, with skin is 223g. This
            means that a typical large apple weighs 223 grams,
            without the core, stem and seeds. If you use <option>--refuse</option>
            here Pantry will think the food weighs too little. Thus
            using the <option>--refuse</option> option typically makes sense only if
            you stick foods on a scale. It is quite handy if, for
            example, you weigh a chicken drumstick before you eat
            it. Otherwise you'd have to weigh the drumstick, eat it,
            and then weigh the bone to figure out how much the meat
            weighed. </para>

        <para> The other approximations tool is the <option>--by-nut</option> option.
            If you use it then Pantry will automatically adjust the
            quantity of a food so that a nutrient you specify will
            be of an amount that you specify. </para>

        <para> For example, let's say I have just eaten half a cup
            of Haagen Dazs chocolate ice cream. I look on the
            container and find that I've just eaten 270 calories.
            But the <filename>starter_database</filename> file does not have Haagen Dazs.
            It does have <literal>Ice creams, chocolate, rich</literal>, but it doesn't
            have the same number of calories per gram. That bothers
            me because I want to know exactly how many calories I
            ate.<footnote>

                <para>Actually <literal>Ice creams, chocolate, rich</literal> comes
                    really close to Haagen Dazs, but since I'm so
                    anal (wouldn't I have to be, to write a program
                    like Pantry?) I want to be more exact. </para>

            </footnote> One way I could deal with this discrepancy
            would be to create a custom food for Haagen Dazs
            chocolate ice cream. We'll learn how to do that later.
            But for now I decide that <literal>Ice creams, chocolate, rich</literal> is
            good enough for my purposes. I figure I will just record
            that I ate 270 calories of <literal>Ice creams, chocolate, rich</literal>:
        </para>

        <example>
            <title>Using the <option>--by-nut</option> option</title>
            pb_verbatim({pantry --search name \
                         "Ice creams, chocolate, rich" \
                         --by-nut Calories 270 \
                         --print name --print info \
                         --goal Calories 2800 \
                         --print goals \
                         --change date 2008-06-20 \
                         --add diary master})
        </example>

        <para> As you can see Pantry adjusted the quantity of
            <literal>Ice creams, chocolate, rich</literal> so that
            it would be equal to 270 calories.
            <option>--by-nut</option> also lends itself to other
            uses, such as determining what quantity of a particular
            food will have a given amount of calories, fat, etc. so
            that you can meet whatever goals you have set for
            yourself. </para>
    </section>

    <section id="paste">
        <title>The <literal>paste</literal> report</title>

        <para> As you've been reading this chapter, one protest you
            might have is that a lot of Pantry commands require a
            lot of typing. I agree; the best solution, however,
            comes by using the features of your shell (such as
            functions, aliases, history, and variables) to help
            speed things up. We'll talk about those in the next
            chapter. Pantry does, however, have one
            innovation to help in a common situation. Often, you'll
            need to look through foods in the <literal>master</literal> collection in
            the <filename>starter_database</filename> file to find what you are looking
            for. Such a search involves two steps: first, you must
            find the right food; and second, often you must find the
            right available unit. </para>

        <para> To merge these two steps into one, there is the <literal>paste</literal>
            report. It shows both the names of foods and their
            available units. The format of the report allows you to
            take the results and cut and paste them. Let's say for
            example I am looking for some sort of strawberry:
        </para>

        <example>
            <title>The <literal>paste</literal> report</title>
            pb_verbatim({pantry --ignore-case \
                         --search name strawberries \
                         --search group fruit \
                         --print paste master | head})
        </example>

        <para> Then I can simply find the line with the right
            available unit and food name and paste that to my
            command line. I'll likely want to add additional options
            after I paste, such as <option>--change
                quantity</option>, <option>--add,</option> or
            <option>--print</option>. Unlike the units report, the
            paste report includes entries for the available units
            <literal>g</literal>, <literal>oz</literal>, and
            <literal>lb</literal>.  Of course, to save space in the
            manual I stuck <userinput>| head</userinput> at the end; instead you'll likely
            want to send the output to your favorite pager, such as
            <command>less</command>. </para>

        <para> In order to actually do the cutting and pasting, just
            use your favorite X terminal emulator, or the cutting
            and pasting features of <ulink
                url="http://http://www.gnu.org/software/screen/">GNU
                screen</ulink>. </para>
    </section> <!-- paste -->

    <section id="saving_quitting">
        <title>Saving and quitting</title>

        <para>When you make changes to a database using the add
            option, those changes are made to the database that is
            currently in memory. Pantry does not write those changes
            to disk unless you tell it to. You can see whether you
            have unsaved changes to the currently open database by
            using the <option>--status</option> option:</para>

        <example>
            <title>Seeing if there are unsaved changes</title>
            pb_verbatim({pantry --status})
        </example>

        <para> Two options, <option>--save</option> and <option>--save-as,</option> will save your
            Pantry database to a file.<footnote>

                <para>The database is written in plain ASCII text,
                    but it's nothing you will want to edit
                    directly.</para>

            </footnote> <option>--save</option> will save the database to the
            filename shown in the Current filename: part of the
            status report; if there is no current filename, Pantry
            will complain with an error message. <option>--save-as</option> takes a
            single argument, which is the name of the file you wish
            to use. <option>--save-as</option> will save your database to that file,
            and it will also change the current filename so that the
            database will be saved to that same file if you later
            use the <option>--save</option> option. </para>

        <para> Here, the current filename is
            <filename>/usr/local/share/pantry/data/starter_database</filename>. That's a
            location that is only writeable by the root user, so if
            I use the <option>--save</option> option, Pantry will give me an error
            and quit. So instead I need to use <option>--save-as</option> to save the
            database to a file in my home directory: </para>

        <example>
            <title>Using the <option>--save-as</option> option</title>
            pb_verbatim({pantry --save-as ~/my_pantry_file})
        </example>


        <para>Finally you may want to shut down the server if you
            are done with Pantry. You do this with the
            <option>--quit</option> option: just run
            <userinput>pantry --quit</userinput>.</para>
        
    </section> <!-- saving_quitting -->

    <section id="files">
        <title>Additional commands to work with files</title>

        <para> You've already learned all the options you'll
            typically need to work with Pantry files:
            <option>--open,</option> <option>--save,</option> and
            <option>--save-as</option>. I'll briefly mention a
            couple of others. First, one of Pantry's limitations is
            that it can work with only one database at a time, and
            one disk file holds one database. So there's no apparent
            way to take the contents of one database and merge it
            with another. Here's where the <option>--read</option>
            option comes in. The <option>--open</option> option
            reads the contents of a disk file into memory,
            clobbering whatever database was already in
            memory.<footnote>

                <para><option>--open</option> does not warn you before it clobbers
                    what's in memory, even when the contents of the
                    database in memory have not been saved. It
                    assumes you know what you're doing.</para>

            </footnote> In contrast, the <option>--read</option> option takes the
            contents of a disk file and adds those contents to
            whatever is in memory. Using this you can, for example,
            merge the contents of two files. </para>

        <para> The second option I'll mention here is simple:
            <option>--close</option> simply wipes the current database from memory,
            leaving you with a blank slate.</para>
    </section> <!-- files -->

    <section id="errors">
        <title>Oops! When things go wrong</title>
        
        <para> Pantry takes a lot of command-line options, and
            sometimes you will get them wrong. Sometimes I get them
            wrong, and I wrote this thing. Sometimes you will also
            try to do something that Pantry does not allow. Examples
            include using a bad pattern for a regular expression
            (such as <literal>ab(c</literal>, which has an unmatched
            parenthesis) or giving a bad value for a numeric trait
            (such as attempting to change the
            <varname>quantity</varname> trait to
            <literal>a1</literal>). File operations have rich
            potential for errors--you might try to open a
            nonexistent file, open a file that is not a Pantry file,
            or save to a place where you don't have write
            permission. </para>

        <para> Whenever Pantry can't do something for whatever
            reason, it will give you an error message and the client
            will quit with a non-zero exit status.<footnote>

                <para> Currently the client will always exit with 1
                    if there was an error--any error. Maybe in
                    future versions
                    the exit code will change depending on the
                    nature of the error. </para>

            </footnote> The server will keep running; it's only the
            client that will quit. Therefore you can easily try
            again. </para>

        <para> If any error occurs, no changes will have been made
            to the database that is in memory or to any disk
            file.<footnote>

                <para> This is a dramatic improvement from earlier
                    versions of Pantry, which had a variety of
                    behaviors when errors happened. </para>

            </footnote>

            That is, the <option>--add,</option>
            <option>--edit,</option> and <option>--delete</option>
            options will have had no effect. If an
            <option>--open,</option> <option>--save,</option>
            <option>--save-as,</option> or <option>--read</option>
            option fails for any reason, then the database that is
            in memory will remain unchanged.</para>

        <para>The server should never quit unexpectedly. If it does,
            it is probably a bug; please report it to
            <email>omari@smileystation.com</email>.
            </para>
    </section>
</chapter> <!-- basics -->

<chapter id="usage_tips">
    <title>Pantry usage tips</title>

    <para>There are a number of ways that you can make your use of
        Pantry more efficient, as this chapter will show you.</para>

    <section id="shell">
        <title>Use your shell</title>

        <para> Pantry was designed to be used in concert with a good
            Unix shell. There are lots of good shells to pick from.
            GNU's Bourne Again Shell (<command>bash</command>) is the most common shell
            on Linux and it's probably the shell you are using if
            you do not know what shell you are using. <command>bash</command> is quite
            serviceable and powerful. </para>

        <para> I'd like to recommend two alternatives to
            <command>bash</command>. <command>zsh</command> is an
            excellent shell for command-line junkies, and it is very
            well documented. <command>zsh</command> is available
            under a free software license, every major Linux
            distribution makes it available in its package
            repositories, and it is also available in Mac OS X.
            Another alternative is <command>fish</command>, the
            Friendly Interactive Shell. <command>fish</command>
            benefits from a sharp focus on usability. By breaking
            with compatibility with other Unix shells,
            <command>fish</command> is clear of clutter and
            predictable to use. <command>fish</command> is also free
            software. It's not as widely distributed as
            <command>zsh</command>, so you might have to compile it
            yourself. </para>

        <para> If you are going to stick with
            <command>bash</command> or <command>zsh</command>, I
            highly recommend you read <citetitle pubwork="book">From
                Bash to Z Shell: Conquering the Command
                Line</citetitle>, by Kiddle, Peck and Stephenson.
            The authors are quite knowledgeable about Unix shells
            (Stephenson currently maintains <command>zsh</command>)
            and this book will teach you many useful tricks. It is
            well worth the price. </para>

        <para>If you are a <command>zsh</command> user you're
            probably familiar with its powerful completion
            capabilities. You'll find a set of completions for
            <command>pantry</command> and <command>pantryd</command>
            at
            <filename>$PREFIX/share/pantry/scripts/_pantry</filename>.
        </para>

        <section id="history">
            <title>History features</title>

            <para>It will be particularly useful to you if you learn
            your shell's features for manipulating your command
            history. Often with Pantry I find myself re-running
            previous commands, with a minor tweak here and there.
            History features make this easy.</para>
        </section> 

        <section id="aliases_functions">
            <title>Aliases and functions</title>

            <para>Another key shell feature is the ability to define
                aliases (which perform simple text substitution) and
                functions (which are programs in their own right.) I
                find both to be invaluable while using Pantry. I use
                functions to define my own custom commands to
                quickly add foods to a day's diary, something which
                I found to be nearly impossible with any other
                nutrient analysis software available. After using
                Pantry for a little while, you'll form your own
                ideas of what sort of functions will help you. For
                inspiration, you can take a look at the
                <filename>$PREFIX/share/pantry/scripts/zsh_functions</filename> file which
                is included in the Pantry distribution, where
                $PREFIX is the prefix you used when you ran the
                configure script. (By default it is <filename>/usr/local</filename>.)
                These are the functions I use. You might find them
                useful as-is, but I encourage you to modify them to
                fit your needs.</para>
        </section>

        <section id="variables">
            <title>Variables and arrays</title>

            <para>A final key shell feature is shell
                variables<footnote>

                    <para>Or, what some shell documentation will
                        call parameters.</para>

                </footnote> and, in particular, arrays. The <option>--list</option>
                and <option>--goal</option> options are much more usable if you take
                advantage of arrays. For example, you might want to
                display several nutrients every time you print a
                goals report. As we saw in the last chapter, typing
                all these nutrients gets tiresome very quickly. The
                solution is to put the nutrients you want into an
                array.<footnote>

                    <para>Under certain circumstances you can do
                        this using regular, "scalar" variables
                        rather than arrays, but you'll be making
                        life hard on yourself.</para>

                </footnote>
                
                Then, instead of typing all of them at the command
                line, you simply type the name of your array
                instead.  </para>

            <para> For reasons related to <ulink
                    url="http://zsh.dotsrc.org/FAQ/zshfaq03.html#l18">word
                    splitting</ulink>, I recommend you use <command>zsh</command> or
                <command>fish</command> if you're going to become an array user, as
                their syntax is a bit friendlier than that of <command>bash</command>
                and <command>ksh</command>. </para>
        </section>
    </section>

    <section id="short">
        <title>Short options and abbreviations</title>

        <para>For instructional purposes, all the examples in this
            manual use double-dashed long options. However, Pantry
            has single-dashed short options for all options you'll
            commonly use. To see what these are, refer to the Pantry
            man page or to <userinput>pantry --help</userinput>.
        </para>

        <para> In many places, Pantry will accept abbreviations
            instead of full words. For example, for long options,
            you may type just enough to make yourself unambiguous.
            This means you can type pantry <option>--q</option>
            instead of pantry <option>--quit.</option> (pantry
            <option>--qu</option> or pantry <option>--qui</option>
            will work too.) You can also do this when you must
            specify a trait name.  Because the first letter of each
            trait is unique, you can specify just a single letter.
            Thus, you can type <userinput>pantry --search n bananas
                master</userinput> instead of <userinput>pantry
                --search name bananas master</userinput>.
            Furthermore, you can abbreviate the names of reports for
            the <option>--print</option> option, and you can
            abbreviate collection names if you are specifying which
            collections to search (you can't abbreviate the argument
            to the <option>--add</option> option.) </para>

        <para> That gives you lots of abbreviating options. For
            instance, instead of typing <userinput>pantry --ignore-case
            --search name bananas --search group fruits --key name
            --print name master</userinput>, you can instead run <userinput>pantry -isn
            bananas -sg fruits -kn -pna m</userinput>.<footnote>

                <para> Pantry is liberal about whether spaces or
                    equal signs must separate option arguments from
                    the option itself; for instance, you can type
                    either <userinput>-pname,</userinput>
                    <userinput>-p name</userinput>,
                    <userinput>--print name</userinput>, or
                    <userinput>--print=name</userinput>. </para>

        </footnote></para>
    </section>

    <section id="collections">
        <title>Files and collections</title>

        <para>Pantry is easiest to work with if you keep all your
            data in a single Pantry file. That's because Pantry does
            not make it very easy for you to move data from one file
            to another. Pantry has collections so that you can sort
            foods within a file in a way that you see fit. I find it
            easiest to keep three collections in my Pantry file. In
            two of these collections, <literal>master</literal> and
            <literal>quick</literal>, every food has a unique name
            trait. That makes it easy for me to find foods using
            simply their <varname>name</varname> trait. There are
            over 7000 foods in my <literal>master</literal>
            collection; it has every food that's in the
            <filename>starter_database</filename> file as well as
            other foods that I created on my own (we'll talk later
            about how you can create foods and recipes.) A second
            collection in my file, <literal>quick</literal>, holds
            only foods that I use frequently. There are about fifty
            foods in here currently. As with the
            <literal>master</literal> collection, every food in my
            <literal>quick</literal> collection has a unique
            <varname>name</varname> trait. Many of the foods in my
            <literal>quick</literal> collection already have their
            <varname>quantity</varname> and <varname>unit</varname>
            traits set to those that I commonly eat.  Finally, I
            have a <literal>diary</literal> collection. When I add
            foods to my diary collection I set the date and meal
            traits to appropriate values.</para>

        <para> This is just the way I do things; you might find a
            better way. For instance, maybe you will start a
            different collection for every day, or for every week.
            You might not find it necessary to keep a separate
            <literal>quick</literal> collection. You might keep a
            diary in the same collection as you keep all your other
            foods. It's up to you. </para>
    </section>

    <section id="using_traits">
        <title>Using traits</title>

        <para> For most traits, Pantry places no constraints on what
            values you can use. This gives you a great deal of
            latitude. For example, if you have several foods you eat
            together, one way to easily account for them in a diary
            is if you create a recipe, which we will talk about
            later. Another way is to simply change the
            <varname>group</varname> traits of these foods so they
            are unique and identical. For example, I often eat a
            particular cereal with a particular milk, so in my
            <literal>quick</literal> collection I have changed the
            group traits of these foods to <literal>Cereal and
                milk</literal>. </para>

        <para> You can use whatever values you want for the date
            trait, but you will find that it is easiest to sort
            dates if you use a YYYY-MM-DD format.</para>
    </section>
</chapter> <!-- usage_tips -->

<chapter id="changing_nuts">
    <title>Creating new foods, and changing the nutrients and
        available units of existing foods</title>

    <para>So far we've only dealt with foods that already exist in
        the <filename>starter_database</filename> file, which comes from data derived
        from the USDA National Nutrient Database for Standard
        Reference. We've copied these foods from one collection to
        another, often changing their traits along the way. But we
        haven't changed the nutrient content of these foods.</para>

    <para> But what if you want to track information about a food
        that is not already in the USDA database? You might find
        there is already a food in the database that is close enough
        for your purposes. However, with Pantry you can easily
        create your own foods with their own nutrient data. Such
        foods are indistinguishable from those in the
        <filename>starter_database</filename> file--except for the fact that you created
        them yourself. In this chapter you'll learn how to create
        foods of your own. </para>

    <para> You'll want to create a food if you already have
        nutrition information for what you are creating--from a
        label, say, or from a website. If you are combining multiple
        ingredients, you'll want to use a recipe instead, which we
        will discuss in the next chapter. </para>

    <section id="create_food">
        <title>Create the food and its traits</title>

        <para>You'll create foods with Pantry the same way you do
            anything else with Pantry: from the command
            line.<footnote>

                <para>This differs dramatically from older versions
                    of Pantry, which used XML files for this
                    purpose.</para>


            </footnote> In this chapter we'll enter nutrition
            information for Heritage Flakes. There is something
            close in the <filename>starter_database</filename>
            file--<literal>Cereals ready-to-eat, wheat and malt
                barley flakes</literal>--but Heritage Flakes is a
            little higher in some nutrients, such as protein, and
            has twice as much fiber. You can get the nutrition
            information <ulink
                url="http://www.naturespath.com/products/cold_cereals">here</ulink>.
        </para>

        <para> To create a new food, use the <option>--create</option> option. This
            will give you a buffer with a single, blank food. Then
            you can use the <option>--change</option> option to change the traits to
            something appropriate, and the <option>--add</option> option to add the
            food to a collection. You can use the <option>--print</option> option to
            print the buffer, as usual. That gives us: </para>

        <example>
            <title>Creating a new food</title>
            pb_verbatim({pantry --create \
                         --change name "Heritage Flakes" \
                         --change quantity 30 \
                         --change unit '^g$' \
                         --print name --print info \
                         --add master})
        </example>

        <para> We changed the quantity to 30 grams because that is the
            quantity that the food label is based upon.<footnote> 
                
                <para>You might wonder why we don't say that the
                    quantity is <literal>3/4</literal> and the unit
                    is <literal>cup</literal>. That's because later
                    we'll discuss adding available units, which is
                    what you'll have to do so that Pantry knows how
                    much a cup of Heritage Flakes weighs.</para>
            </footnote>
                
                It's essential that the quantity and units be
                correct when you add nutrient information. </para>
    </section>

    <section id="create_units">
        <title>Add available units</title>

        <para>Next you can add available units to your food, if you
            wish. Pantry will automatically supply your food with
            the available units <literal>g</literal>, <literal>oz</literal>, and <literal>lb</literal>, so there is no need
            to add those. From the label we see that 3/4 of a cup of
            Heritage Flakes weighs 30 grams. This means a cup weighs
            40 grams.  Using this knowledge we can use the
            <option>--change-avail-unit</option> option.  Its first argument is the name
            of an available unit that you wish to create or change,
            and its second argument is the weight of that available
            unit, in grams.</para>

        <example>
            <title>Adding an available unit</title>
            pb_verbatim({pantry --exact-match \
                         --search name "Heritage Flakes" \
                         --change-avail-unit cup 40 \
                         --edit master})
        </example>
    </section>

    <section id="create_nuts">
        <title>Create nutrients</title>

        <para> Next you can add nutrients. You can use whatever
            nutrient names you wish, but for consistency's sake you
            might wish to use names that are identical to those used
            in the <filename>starter_database</filename> file. (To get a list of all
            nutrient names used in the <literal>master</literal> collection of the
            <filename>starter_database</filename> file, you can run <userinput>pantry --print Nuts
            master</userinput>. That command might take several seconds to run,
            especially on a slow machine.)</para>

        <para> On U.S. food labels, many nutrients are given as
            percentages. You might just enter these percentages if
            you wish. You can convert them to actual values using
            <ulink
                url="http://www.fda.gov/FDAC/special/foodlabel/dvs.html">this
                chart</ulink>. Right now we'll just skirt that issue
            by entering only macronutrients.<footnote>

                <para>Pantry comes with a script that helps you
                    enter new foods, and it converts these
                    percentages to actual values. We'll talk about
                    this script later.</para>

            </footnote> Be sure to use the <option>--edit</option> option so your
            changes are permanent.</para>

        <example>
            <title>Adding nutrients</title>
            pb_verbatim({pantry --exact-match \
                         --search name "Heritage Flakes" \
                         --change-nut "Calories" 120 \
                         --change-nut "Total Fat, g" 1 \
                         --change-nut "Saturated Fat, g" 0 \
                         --change-nut "Trans Fat, g" 0 \
                         --change-nut "Cholesterol, mg" 0 \
                         --change-nut "Sodium, mg" 130 \
                         --change-nut "Total Carbohydrate, g" 24 \
                         --change-nut "Dietary Fiber, g" 6 \
                         --change-nut "Sugars, g" 4 \
                         --change-nut "Protein, g" 4 \
                         --edit master})
        </example>
    </section>

    <section id="check">
        <title>Check your work</title>

        <para>That should do it. Let's make sure:</para>
        <example>
            <title>Seeing the new food</title>
            pb_verbatim({pantry --exact-match \
                         --search name "Heritage Flakes" \
                         --print name --print info --print nuts \
                         master})
         </example>
                     
         <para>In this example, for instructional purposes we used
             more than one pantry command to add the traits,
             nutrients, and available units. You can do all this in
             one command, however. You can even add the food to
             collections and <option>--print</option> it, all in the same
             command.</para>
    </section>

    <section id="food_script">
        <title>The <command>addFoods</command> script</title>

        <para>You might find it more convenient to enter the
            commands required into a simple shell script, since
            there are so many to type. Alternatively, you can use
            the <command>addFoods</command> script, which you will find in
            <filename>$PREFIX/share/pantry/scripts/addFoods</filename>, where $PREFIX is the
            prefix you used when you installed Pantry. (By default
            this is <filename>/usr/local</filename>.) This script takes the name of an
            input file, which is simply a number of <command>zsh</command> variables
            containing the data for the food. This script also
            automatically converts micronutrients, which are
            expressed on US food labels as percentages, to actual
            values. To get an idea how the script works, just take a
            look at the script itself. Alternatively, you will find a number
            of sample input files for this script in the
            <filename>$PREFIX/share/pantry/examples/foods</filename> directory. To
            get started you can just model your input after one of
            these files.</para>

        <para>The <command>addFoods</command> script is written for <command>zsh</command>, so you'll have
            to install <command>zsh</command> in order to use it.</para>
    </section>

    <section id="editing_foods">
        <title>Commands to edit the nutrients and available units of
            foods</title>

        <para>Pantry has a number of options to edit the nutrients
            and available units of existing foods. Changing
            nutrients and available units is similar to changing
            traits: Pantry makes the changes you wish, but only to
            foods that are in the buffer. To make your changes
            permanent, you need to use the <option>--add</option> or
            <option>--edit</option> option.  We've already seen the
            <option>--change-nut</option> and
            <option>--change-avail-unit</option> options. These work
            not only for adding new nutrients or available units,
            but also for modifying existing ones. Remember that the
            first argument to <option>--change-nut</option> and
            <option>--change-avail-unit</option> is not a regular
            expression--it is the exact name of the nutrient you
            wish to add or change, and it is always case sensitive,
            even if you use the <option>--ignore-case</option>
            option.</para>

        <para>If you wish to change the name of an existing
            nutrient, use <option>--rename-nut.</option> It takes
            two arguments.  The first is a pattern for the nutrient
            name you wish to change. As with the
            <option>--search</option> option, this is a regular
            expression, unless you use the
            <option>--exact-match</option> option.
            <option>--rename-nut</option> also respects the
            <option>--ignore-case</option> option. The second
            argument is the new nutrient name.</para>

        <example>
            <title>Using <option>--rename-nut</option></title>
            pb_verbatim({pantry --search name "Heritage Flakes" \
                         --rename-nut "Total Carbohydrate, g" Carbs \
                         --print name --print info --print nuts \
                         master})
        </example>

        <para> For each food in the buffer, the pattern given in the
            first argument to <option>--rename-nut</option> must match either no nutrients
            or one nutrient of each food. If the pattern matches no
            nutrients, Pantry will make no change to that food. If
            the pattern matches one nutrient, then Pantry will
            rename that nutrient. If the pattern  matches more than
            one nutrient, Pantry will give you an error message and
            quit.</para>

        <para> The <option>--rename-avail-unit</option> option
            renames available units (except for
            <literal>g</literal>, <literal>oz</literal>, and
            <literal>lb</literal>, which you cannot rename);
            otherwise, it is identical to the
            <option>--rename-nut</option> option. As with the
            <option>--rename-nut</option> option, the
            <option>--rename-avail-unit</option> pattern must match
            either zero or one available units for every food in the
            buffer (excluding <literal>g</literal>,
            <literal>oz</literal>, or <literal>lb</literal>);
            otherwise, Pantry will give you an error and quit.
        </para>

        <example>
            <title>Using
                <option>--rename-avail-unit</option></title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --rename-avail-unit large big \
                         --print name --print units master})
        </example>

        <para>To delete nutrients, use
            <option>--delete-nuts.</option> This option takes one
            argument, a pattern for nutrients you wish to delete.
            This pattern is a regular expression, unless you use
            <option>--exact-match,</option> and it respects
            <option>--ignore-case.</option> It deletes every
            nutrient that matches the pattern, and it doesn't
            complain if no nutrients match the pattern: </para>

        <example>
            <title>Using <option>--delete-nuts</option></title>
            pb_verbatim({pantry --search name "Heritage Flakes" \
                         --delete-nuts Fat \
                         --print name --print nuts \
                         master})
        </example>

        <para> The <option>--delete-avail-units</option> option deletes available
            units, other than <literal>g</literal>, <literal>oz</literal>, and <literal>lb</literal>. In all other respects
            it is identical to the <option>--delete-nuts</option> option: </para>

        <example>
            <title>Using <option>--delete-avail-units</option></title>
            pb_verbatim({pantry --search name "Apples, raw, with skin" \
                         --delete-avail-units large \
                         --print name --print units master})
        </example>
    </section>
</chapter> <!-- changing_nuts -->

<chapter id="recipes">
    <title>Creating recipes</title>

    <para>Creating new foods works great if you already know the
        nutrient content of a food--if, for example, you can pull
        the information from a label. Recipes, on the other hand,
        are ideal if you are creating a food from other foods and
        you don't know the nutrient content of the final food.</para>

    <para> In Pantry, recipes are mostly like other foods. They are
        different in that they have two additional traits:
        <varname>yield</varname> and
        <varname>instructions</varname>. <varname>yield</varname>
        indicates the total weight, in grams, of one batch of this
        recipe. This is quite handy because recipes often lose water
        as you cook them. Of course you can only know the exact
        yield after you have cooked a recipe and have weighed it. If
        you do not supply a <varname>yield</varname> trait for a
        recipe, Pantry will guess the yield by adding up the weight
        of all the recipe's ingredients.
        <varname>instructions</varname> is simply food preparation
        notes, or whatever you want. </para>

    <section id="create_recipe">
        <title>Create the recipe and its traits</title>

        <para>This step is similar to the first step of creating a
            food: you use the <option>--create</option> option, and then you set the
            traits as you wish.</para>

        <example>
            <title>Creating a recipe</title>
            pb_verbatim({pantry --create --change name "Easy Corn Bread" \
                         --change group "Baked Products" \
                         --change quantity 50 \
                         --change unit '^g$' \
                         --change instructions 'pb_corn_bread_instructions' \
                         --add master})
        </example>
    </section>

    <section id="ingredients">
        <title>Add ingredients</title>

        <para>To add ingredients to a food, you use the
            <option>--add-ingredients</option> option, which takes a single argument,
            which is the name of the collection to add foods
            from.<footnote>

                <para>You can abbreviate the argument to the
                    shortest unambiguous name for the collection,
                    just as you can abbreviate collections that are
                    positional arguments to the pantry
                    command.</para>

            </footnote> Pantry adds all the foods from the
            collection as ingredients. Thus, the easiest way to
            create recipes is to add all the ingredients to a
            temporary collection--<literal>ingredients</literal>,
            perhaps--and then use that collection as an argument to
            <option>--add-ingredients.</option> You can just delete
            the collection with <option>--delete</option> when you
            are done. </para>

        <example>
            <title>Adding ingredients to a single collection</title>
            pb_verbatim({pantry --exact-match \
            --search name \
            "Wheat flour, white, all-purpose, enriched, unbleached" \
            --change quantity "1 1/4" --change unit cup \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Cornmeal, whole-grain, yellow" \
            --change quantity "3/4" --change unit cup \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Sugars, granulated" \
            --change quantity "1/4" --change unit cup \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Leavening agents, baking powder, double-acting, straight phosphate" \
            --change quantity "2" --change unit tsp \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Salt, table" \
            --change quantity "1/2" --change unit tsp \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Milk, reduced fat, fluid, 2% milkfat, with added vitamin A" \
            --change quantity 1 --change unit cup \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Oil, corn and canola" \
            --change quantity "1/4" --change unit cup \
            --add ingredients master})
        
            pb_verbatim({pantry --exact-match \
            --search name \
            "Egg, whole, raw, fresh" \
            --change quantity 1 --change unit large \
            --add ingredients master})
        </example>
        
        <para>Okay, now we can add the ingredients to the food
            itself. After adding them to the food we have no use for
            the collection so we can just delete it. </para>

        <example>
            <title>Add ingredients to the food</title>
            pb_verbatim({pantry --search name "Easy Corn Bread" \
                         --add-ingredients ingredients \
                         --edit master})
            pb_verbatim({pantry --delete ingredients})
        </example>
    </section>

    <section id="recipe_units">
        <title>Add available units</title>

        <para>You do this just as you would for a food. We won't add
        any available units here, but you will often find it is
        handy to add an available unit for serving. To do this you
        can simply divide a recipe's yield by the number of
        servings. In the next section you'll see how to find a
        food's estimated yield if you haven't weighed the yield
        yourself.</para>

    </section>

    <section id="check_recipe">
        <title>Seeing your new recipe</title>

        <para> In order to see your new recipe, you use the <literal>recipe</literal>
            report. This report shows the <varname>yield</varname> trait, ingredients,
            and <literal>instructions</literal> trait for a recipe. Recipes and foods are
            fully interchangeable in Pantry--for instance, a recipe
            can be the ingredient for another recipe.</para>

        <example>
            <title>The <literal>recipe</literal> report</title>
            pb_verbatim({pantry --search name "Easy Corn Bread" \
                         --print name --print info --print recipe \
                         master})
        </example>

        <para> For ingredients, Pantry prints the
            <varname>quantity</varname> trait, the
            <varname>unit</varname> trait, and the
            <varname>name</varname> trait. Pantry will print the
            <varname>comment</varname> trait's value in parentheses,
            if the comment trait is set at all. Pantry prints
            ingredients by sorting their <varname>order</varname>
            traits in ascending order, even though Pantry does not
            show the order traits for the ingredients. So, if you
            want to ensure that your ingredients are shown in a
            certain order, set your <varname>order</varname> trait
            for each ingredient accordingly. </para>

        <para>A recipe's nutrient makeup is determined by all its
            ingredients. The nutrient makeup is scaled depending
            upon the <varname>yield</varname> trait, which is why
            Pantry will be more accurate if you weigh the yield of a
            recipe and enter it in. If the yield trait of a recipe
            is not set (of if you explicitly set it to zero) then in
            the <literal>recipe</literal> report Pantry will show an
            estimate for the recipe's yield, as it has done here.
            Pantry gets this estimate by adding the weight of all of
            a recipe's ingredients. Typically this estimate will be
            high, as cooking typically causes some of the water in a
            recipe to evaporate. </para>

    </section>

    <section id="addRecipes">
        <title>The <filename>addRecipes</filename> script</title>

        <para> Since you have to type so much in order to add a
            recipe, you might want to put the commands in a simple
            shell script. Also, just as there is an <filename>addFoods</filename>
            script, there is also an <filename>addRecipes</filename>
            script. The script allows you to define a few shell
            variables in a file, which you then feed to the script
            in order to create your recipe. You'll find it at
            <filename>$PREFIX/share/pantry/scripts/addRecipes</filename>,
            and there are sample input files at
            <filename>$PREFIX/share/pantry/examples/recipes</filename>,
            where $PREFIX is the prefix you used when you installed
            Pantry. (It defaults to
            <filename>/usr/local</filename>.) </para>

        <para> Like the <command>addFoods</command> script, the
            <command>addRecipes</command> script is written for
            <command>zsh</command>.</para>

        <para>If you use the <filename>addRecipes</filename> script,
            also take a look at the <filename>ingrlist</filename>
            script, which will help you as you look up ingredients
            to add to input files for
            <filename>addRecipes</filename>. </para>

    </section>

    <section id="edit_recipe">
        <title>Editing recipes</title>

        <para>Recipes and foods in Pantry are nearly fully
            interchangeable. You can edit the traits and available
            units for a recipe in the same way as you do for a food.
            Nutrients, however, are a bit different. In a regular
            food, you input all the nutrient data. For a recipe, the
            nutrient data is typically calcualted from the
            ingredients. You can use <option>--change-nut</option>
            on a recipe. This will create a nutrient that will
            override the automatically-calculated nutrient of the
            same name, if there is one. For recipes,
            <option>--rename-nut</option> only works for nutrients
            you have entered using <option>--change-nut,</option>
            and <option>--delete-nuts</option> only deletes
            nutrients that you have set using
            <option>--change-nut</option> or
            <option>--rename-nut.</option> If you delete a nutrient
            you have set using <option>--change-nut</option> or
            <option>--rename-nut</option>, Pantry
            will then revert to using the automatically-calculated
            nutrient, if there is one. </para>
    </section>

</chapter> <!-- recipes -->

<appendix id="limitations">
    <title>Pantry limitations</title>

    <para>Pantry isn't perfect. It has some limitations you might
        want to know about.</para>

    <section id="eight_bit">
        <title>No multibyte or locale awareness</title>

        <para>Pantry is horribly U.S. centric. It knows nothing
            about multibyte character encodings, such as UTF-8.
            Furthermore, it knows nothing about locales, so <ulink
                url="http://en.wikipedia.org/wiki/Collation">collation</ulink>
            is performed in what has sometimes been called
            ASCIIbetical order. </para>

        <para>Strictly speaking you could use any encoding with
            Pantry, as long as it is a single-byte one. For
            instance, Pantry would have no problem with characters
            from the ISO-8859-1 character set. However, I recommend
            you stick with US-ASCII, for two reasons. First, most
            Linux distributions these days use UTF-8 for their
            terminal encoding. If you use characters solely from the
            <ulink url="http://en.wikipedia.org/wiki/ASCII">ASCII
                character set</ulink>, then UTF-8 is identical to
            ASCII.  However, if you use characters from <ulink
                url="http://en.wikipedia.org/wiki/ISO/IEC_8859-1">ISO-8859-1</ulink>,
            and your terminal is set to UTF-8, then you will really
            be using multibyte characters, which Pantry does not
            know how to handle. Second, even if you get your
            terminal set up correctly to use a non-ASCII single-byte
            encoding, your file may behave differently if you later
            use it on a different computer with a different terminal
            encoding.  ASCII, on the other hand, is an encoding
            which will work nearly anywhere. </para>

        <para> Converting Pantry to use multibyte encodings
            correctly would not be terribly difficult. Pantry could
            ensure that all input data is converted to UTF-8 for
            internal use, and then convert it to the proper encoding
            when sent to the user's terminal. Another issue would be
            regular expressions. I've never seen regular expression
            routines from a UNIX standard C library that claim to be
            multibyte aware, so they probably are not. A
            straightforward solution would be to use PCRE, which can
            handle UTF-8.</para>

        <para> The reason I haven't made Pantry handle multibyte
            properly is because all the documentation is in English
            and the interface is in English. This is not likely to
            change soon, as Pantry has no community of users to
            translate it, and English is the only language I know.
            If you are fluent in written Enlish, then likely it is
            not much of a limitation to use only US-ASCII with
            Pantry. I could one day make Pantry multibyte aware, if
            it seemed someone cared about that and if I had lots of
            free time.</para>
    </section>

    <section id="ram_usage">
        <title>High RAM usage</title>

        <para>Pantry can use lots of memory. Well, whether it is
            "lots" depends on what you think a lot is. When I open
            the <filename>starter_database</filename> file on my computer, Pantry
            consumes about 30 MB of memory. I don't think that is
            too bad, but then, my least capable computer has 512 MB
            of RAM, and typically I don't even use half of
            that.</para>

        <para> Pantry consumes so much memory because it stores so
            much data. Most of the foods in the <filename>starter_database</filename>
            file have a few dozen nutrients; that's what consumes
            the vast majority of storage space. Therefore, if you
            want to keep all the foods in the <filename>starter_database</filename> file
            but you want to cut memory usage, the easiest way to do
            it is to delete nutrients you don't need, which of
            course is easy with the <option>--delete-nuts</option> option. The less
            data you store, the smaller Pantry's memory footprint
            will be. </para>

        <para>A great deal of code in Pantry 26 was rewritten so
            that Pantry is more frugal with memory. Though the
            starter_database file currently consumes 30 MB of memory
            on my machine, with older versions of Pantry this was 55
            MB. Pantry 26 is also a bit faster than older versions
            of Pantry, too. </para>

    </section>

    <section id="one_file">
        <title>Only one file at a time may be open</title>

        <para>In Pantry each server can work only with one file at a
            time. This could possibly be changed, but right now I
            don't see how changing this would do anything other than
            make the user interface more complex.</para>

    </section>

    <section id="collection_size">
        <title>Size of collections, number of collections, number of
            nutrients, etc.</title>

        <para>There are limitations to how many foods you can have
            in a collection, how many collections you may have in a
            single database, etc. These limitations will vary
            depending upon the nature of your standard C++ library.
            On my machine, for example, I can have (in theory) about
            4 billion collections. Each collection can have a much
            lower number foods: only about 1 billion. For all
            practical purposes you'd run out of memory before you
            hit these limitations. </para>

    </section>

    <section id="approximate_numbers">
        <title>Numbers are approximations</title>

        <para>Gasp! This is a nutrition analysis software package,
            and the numbers are approximations?! Yes. Internally
            Pantry uses floating point numbers. Such numbers
            are, by their very nature, <ulink
                url="http://en.wikipedia.org/wiki/Floating_point">approximate</ulink>.
            We're talking typical approximations on the order of,
            for example, fractions of a calorie--not tens of
            calories or even a single calorie.</para>

        <para>Though Pantry could be made more precise, this would
            come at the expense of more memory usage and more code.
            Furthermore, the only result would be precise
            calculations of nutrition data--data which is, by its
            very nature, also approximate. So at this point I'm
            inclined to say that Pantry's approximations are "good
            enough." </para>

    </section>
</appendix> <!-- limitations -->

<appendix id="sr_differences">
    <title>How the USDA National Nutrient Database for Standard
        Reference became the <filename>starter_database</filename> file</title>

    <para>If you are curious about how the data from USDA's National
        Nutrient Database is translated into a form Pantry can
        understand, and whether any data was lost along the way,
        you've come to the right place.</para>

    <para>USDA releases its database in the form of about a dozen
        plain text files, which you can download from the <ulink
            url="http://www.ars.usda.gov/main/site_main.htm?modecode=12354500">USDA
            website</ulink>. If the data in Pantry looks familiar,
        it's because this USDA data forms the basis for pretty much
        any food database you will find in the US, either on the Web
        or on your desktop, in free software and in proprietary
        products.  </para>

    <para>I have written a <command>zsh</command> script to convert the USDA database
        into a series of over 7,000 Pantry commands--one command for
        each food in the database. You can find the script at
        <filename>$PREFIX/share/pantry/scripts/convert_sr.zsh</filename>.<footnote>

            <para>This is a huge change from earlier versions of
                Pantry, which included Python code to import the
                USDA database. I've found these sorts of tasks to be
                easiest with <command>zsh</command>, though ksh would work fine too.
                Maybe Perl would work well, but I've never had any
                desire to learn Perl. C++ would be very nasty for a
                task such as this.</para>

        </footnote> This script renames some nutrients from names
        like <literal>Fatty acids, total trans</literal> to
        <literal>Trans Fat</literal>. It also discards some of the
        gram weights (or, in Pantry lingo, available units) from the
        <filename>WEIGHT.txt</filename> file. For example, the
        <filename>WEIGHT.txt</filename> file contains weights such
        as <literal>lb</literal> which Pantry provides
        automatically. Also, it provides some weights where the
        quantity is more than one--it might have a weight for, say,
        2 slices of pizza rather than for 1 slice of pizza. I
        thought hard about what to do with data like this before
        finally deciding to just discard it. The only accurate way
        to keep this data would be to manually go through it and
        edit the descriptions accordingly. </para>

    <para> The script spits the Pantry commands to standard output,
        which I then save to a file and use to create the
        <filename>starter_database</filename> file. You can even do
        it yourself. You might do this if, for instance, USDA has
        released a new database and you don't want to wait for me to
        get around to releasing a new version of Pantry. Beware,
        though: the <command>convert_sr.zsh</command> file works
        fine with SR20 and SR21 (USDA calls the database simply
        "SR"), but future SR releases might change their format and
        break the script. I doubt this would happen, but it's
        possible. Also, an earlier release of SR20 had small
        irregularities in the data that completely broke this
        script, but a subsequent release of SR20 fixed this
        problem.</para>

    <para> If you want to see a list of all the nutrients in the
        <filename>starter_database</filename> file, open it and run
        <userinput>pantry -p Nuts master</userinput>. It will be
        obvious how these nutrients match up with those in SR, even
        though I changed the names a bit. This command may take a
        few seconds to run, especially on slow machines.</para>
</appendix>

<appendix id='reference'>
    <title>Reference pages</title>
    <para>
	
	This appendix contains reference pages for the commands that
	Pantry uses. They are identical to the man pages; indeed,
        the man pages and this document are generated from the same
        source.

    </para>
    <refentry id="pantry-man">
        <refentryinfo>
            <date>pb_release_date</date>
            <productname>Pantry</productname>
            <productnumber>pb_version</productnumber>
            <copyright><year>2007-2008</year><holder>Omari
                    Norman</holder></copyright>
        </refentryinfo>

	<refmeta>
	    <refentrytitle>pantry</refentrytitle>
	    <manvolnum>1</manvolnum>
	</refmeta>

	<refnamediv>
	    <refname>pantry</refname>
	    <refpurpose>nutrient tracking and analysis</refpurpose>
	</refnamediv>

	<refsynopsisdiv>
	    <cmdsynopsis>
		<command>pantry</command>
		<arg rep="repeat">options</arg>
		<arg rep="repeat"><replaceable>collection</replaceable></arg>
	    </cmdsynopsis>
	</refsynopsisdiv>

	<refsect1 id="man-description">
	    <title>Description</title>
	    <para>

                <command>pantry</command> copies foods from
                <replaceable>collection</replaceable>s into a
                buffer. All foods are copied, unless one or more
                <option>--search</option> options are specified, in which
                case only foods that match the patterns of every
                <option>--search</option> option are copied.
                <command>pantry</command> then changes every food in
                the buffer using any <option>--change</option>
                options specified as well as any options for
                changing nutrients, available units, and
                ingredients.

	    </para>
	    <para>

		If <option>--edit</option> or
		<option>--delete</option> is specified,
		<command>pantry</command> deletes the unchanged
		foods from the corresponding original
		<replaceable>collection</replaceable>s. If
		<option>--edit</option> is specified,
		<command>pantry</command> adds changed foods to
		corresponding original
		<replaceable>collection</replaceable>s. 

	    </para>
	    <para>

		If <option>--print
		    <replaceable>REPORT</replaceable></option> is
		specified, buffer is printed using
		<replaceable>REPORT</replaceable> Buffer is unsorted
                unless one or more <option>--key
                    <replaceable>TRAIT</replaceable></option> is
                specified. Sorting may be affected by one or more
                <option>--list</option> options.

	    </para>
	    <para>

                If <option>--add
                    <replaceable>COLLECTION</replaceable></option>
                is specified, each food in the buffer is added to
                <replaceable>COLLECTION</replaceable>.

	    </para>
            <para>

                <command>pantry</command> communicates with a
                <command>pantryd</command> server, see pantryd(1).

            </para>
	</refsect1> <!-- man-description -->

	<refsect1>
	    <title>Options</title>

            <para><replaceable>TRAIT</replaceable> is any one
                of: </para>

            <itemizedlist>

                <listitem><para>name</para></listitem>
                <listitem><para>group</para></listitem>
                <listitem><para>quantity</para></listitem>
                <listitem><para>unit</para></listitem>
                <listitem><para>date</para></listitem>
                <listitem><para>meal</para></listitem>
                <listitem><para>comment</para></listitem>
                <listitem><para>order</para></listitem>
                <listitem><para>refuse</para></listitem>
                <listitem><para>percent-refuse</para></listitem>
                <listitem><para>yield</para></listitem>
                <listitem><para>instructions</para></listitem>

            </itemizedlist>

            <para><replaceable>TRAIT</replaceable> names may be
                abbreviated.</para>

            <para><replaceable>PATTERN</replaceable> is an extended
                regular expression, unless
                <option>--ignore-case</option> is on.</para>

            <para> Most options other than file and server control
                options may appear on the command line more
                than once; the effect of multiple options is
                cumulative.</para>

            <variablelist>
                <title>File and server control</title>

                <varlistentry>
                    <term>
                        <option>--open</option>
                        <replaceable>filename</replaceable>
                    </term>

                    <listitem>
                        <para>

                            Close currently open database and open
                            <replaceable>filename</replaceable>
                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--read</option>
                        <replaceable>filename</replaceable>
                    </term>

                    <listitem>
                        <para>

                            Append contents of
                            <replaceable>filename</replaceable> to
                            currently open database

                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--close</option>
                    </term>

                    <listitem>
                        <para>

                            Close currently open database

                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--save</option>
                    </term>

                    <listitem>
                        <para>

                            Save currently open database

                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--save-as</option>
                        <replaceable>filename</replaceable>
                    </term>

                    <listitem>
                        <para>

                            Save currently open database under a
                            different
                            <replaceable>filename</replaceable>

                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--quit</option>
                    </term>

                    <listitem>
                        <para>

                            Shut down server

                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--status</option>
                    </term>

                    <listitem>
                        <para>

                            Display server status and database
                            information: names of collections in
                            database and the number of foods in each
                            collection, and what filename will be
                            used if <option>--save</option> option
                            is used

                        </para>
                    </listitem>
                </varlistentry>
            </variablelist>

            <variablelist>
                <title>Food selection</title>

                <varlistentry>
                    <term>
                        <option>--search</option>
                        <replaceable>TRAIT</replaceable>
                        <replaceable>PATTERN</replaceable>
                    </term>
                    <term>
                        <option>-s</option>
                        <replaceable>TRAIT</replaceable>
                        <replaceable>PATTERN</replaceable>
                    </term>
                    
                    <listitem>
                        <para>

                            Include in buffer only foods whose
                            <replaceable>TRAIT</replaceable>
                            matches
                            <replaceable>PATTERN</replaceable>.

                        </para>
                    </listitem>
                </varlistentry>
            </variablelist>
                    
	    <variablelist>
		<title>Changing food traits</title>

		<varlistentry>
		    <term>
			<option>--change</option>
			<replaceable>TRAIT</replaceable>
			<replaceable>string</replaceable>
		    </term>
		    <term>
			<option>-c</option>
			<replaceable>TRAIT</replaceable>
			<replaceable>string</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Change <replaceable>TRAIT</replaceable>
                            <replaceable>string</replaceable>. If
                            <replaceable>TRAIT</replaceable> is
                            <parameter>unit</parameter>,
                            <replaceable>string</replaceable> is a
                            pattern that must match exactly one of
                            the food's available units. If
                            <replaceable>TRAIT</replaceable> is
                            <parameter>quantity</parameter> or
                            <parameter>unit</parameter>,
                            <replaceable>string</replaceable> must
                            be convertible to a non-negative number.
                            If <replaceable>TRAIT</replaceable> is
                            <parameter>percent-refuse</parameter>,
                            <replaceable>string</replaceable> must
                            be convertible to a number between 0 and
                            100, inclusive.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--refuse</option>
		    </term>
                    <term>
                        <option>-r</option>
                    </term>
		    
		    <listitem>
			<para>

                            Reduce food quantity by percent refuse.

			</para>
		    </listitem>
		</varlistentry>
            </variablelist>

            <variablelist>
                <title>Changing nutrients, available units, and
                    ingredients</title>

		<varlistentry>
		    <term>
			<option>--change-nut</option>
			<replaceable>string</replaceable>
			<replaceable>number</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Change nutrient whose name is
                            <replaceable>string</replaceable> to
                            <replaceable>number</replaceable>.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--rename-nut</option>
			<replaceable>pattern</replaceable>
			<replaceable>string</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Rename nutrient whose name matches
                            <replaceable>pattern</replaceable> to
                            <replaceable>string</replaceable>.
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--delete-nuts</option>
			<replaceable>PATTERN</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Delete all nutrients matching
                            <replaceable>PATTERN</replaceable>.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--change-avail-unit</option>
			<replaceable>string</replaceable>
			<replaceable>number</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Change available unit whose name is
                            <replaceable>string</replaceable> to
                            <replaceable>number</replaceable>.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--rename-avail-unit</option>
			<replaceable>pattern</replaceable>
			<replaceable>string</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Rename available unit whose name matches
                            <replaceable>pattern</replaceable> to
                            <replaceable>string</replaceable>.
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--delete-avail-units</option>
			<replaceable>PATTERN</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Delete all available units matching
                            <replaceable>PATTERN</replaceable>.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--add-ingredients</option>
			<replaceable>COLLECTION</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Add ingredients from
                            <replaceable>COLLECTION</replaceable>.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--delete-ingredients</option>
			<replaceable>PATTERN</replaceable>
		    </term>
		    
		    <listitem>
			<para>

                            Delete ingredients whose name trait
                            matches
                            <replaceable>PATTERN</replaceable>.

			</para>
		    </listitem>
		</varlistentry>
            </variablelist>

            <variablelist>
                <title>Search and edit options</title>

		<varlistentry>
		    <term>
			<option>--ignore-case</option>
                    </term>
                    <term>
			<option>-i</option>
		    </term>
		    
		    <listitem>
			<para>

                            All patterns are case insensitive.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--exact-match</option>
                    </term>
                    <term>
                        <option>-x</option>
                    </term>

		    <listitem>

                        <para>All patterns must exactly match their
                            subjects (turns off regular
                            expressions).</para>

		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
                        <option>--edit</option>
		    </term>

		    <listitem>

                        <para>Edit foods in place</para>

		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--delete</option>
		    </term>

		    <listitem>

			<para> Delete matching foods</para>

		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--create</option>
		    </term>

		    <listitem>

			<para> Create a new food from scratch. When
                        this option is used, Pantry does not copy
                        foods from any collections specified on the
                        command line, and the <option>--edit</option>
                        and <option>--delete</option> options are
                        ignored.</para>

		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--limit</option>
                        <replaceable>number</replaceable>
		    </term>

		    <listitem>

                        <para> Limit number of foods in buffer to
                            <replaceable>number</replaceable></para>

		    </listitem>
		</varlistentry>
            </variablelist>

            <variablelist>
                <title>Reporting</title>

                <varlistentry>
                    <term>
                        <option>--print</option>
                        <replaceable>report</replaceable>
                    </term>
                    <term>
                        <option>-p</option>
                        <replaceable>report</replaceable>
                    </term>

                    <listitem>

                        <para>Print <replaceable>report</replaceable>
                            (see "Reports" section below)</para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--key</option>
                        <replaceable>TRAIT</replaceable>
                    </term>
                    <term>
                        <option>-k</option>
                        <replaceable>TRAIT</replaceable>
                    </term>

                    <listitem>

                        <para>Use <replaceable>TRAIT</replaceable>
                            as a sorting key. If the first letter of
                            <replaceable>TRAIT</replaceable> is
                            lowercase, sort in ascending order; if
                            the first letter of
                            <replaceable>TRAIT</replaceable> is
                            uppercase, sort in descending order.
                        </para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--goal</option>
                        <replaceable>nutrient-name</replaceable>
                        <replaceable>amount</replaceable>
                    </term>
                    <term>
                        <option>-g</option>
                        <replaceable>nutrient-name</replaceable>
                        <replaceable>amount</replaceable>
                    </term>

                    <listitem>

                        <para>Add a nutrient intake goal for use by
                            the nutrient-related reports, where
                            <replaceable>nutrient-name</replaceable>
                            is the nutrient for which you wish to
                            add a goal, and
                            <replaceable>amount</replaceable> is a
                            string, convertible to a non-negative
                            number, that is the amount of the goal.
                        </para>

                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--list</option>
                        <replaceable>TRAIT</replaceable>
                        <replaceable>string</replaceable>
                    </term>
                    <term>
                        <option>-l</option>
                        <replaceable>TRAIT</replaceable>
                        <replaceable>string</replaceable>
                    </term>

                    <listitem>

                        <para>Add <replaceable>string</replaceable>
                            to the list of strings that will be used
                            when <replaceable>TRAIT</replaceable> is
                            used as a sorting key. When
                            <replaceable>TRAIT</replaceable> is
                            equal to one of these values, it will be
                            sorted in the order specified. </para>

                    </listitem>
                </varlistentry>
            </variablelist>

	    <variablelist>
                <title>Adding results to collections</title>

		<varlistentry>
		    <term>
			<option>--add</option>
			<replaceable>COLLECTION</replaceable>
		    </term>
		    <term>
			<option>-a</option>
			<replaceable>COLLECTION</replaceable>
		    </term>

		    <listitem>
			<para>
			    Add buffer to
			    <replaceable>COLLECTION</replaceable>.
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--auto-order</option>
		    </term>
		    <term>
			<option>-o</option>
		    </term>

		    <listitem>

			<para> When adding each food to collections
			    specified with <option>--add</option>,
			    <command>pantry</command> will search
			    the collection for other foods with identical
			    <varname>date</varname> and
			    <varname>meal</varname> traits. The
			    result will be sorted in ascending order
			    by the <parameter>order</parameter>
			    trait. If the highest food's
			    <parameter>order</parameter> trait
			    matches the regular expression
			    <literal>^[0-9]{4}$</literal>, then
			    <command>pantry</command> will take the
			    highest food's
			    <parameter>order</parameter> trait,
			    remove any leading zeroes, remove the
			    last digit, and increment the result by
			    one. The result is multiplied by ten,
			    and then is left-padded with zeroes so
			    that it is four characters long.
			    <command>pantry</command> will then
			    change the <varname>order</varname>
			    trait of the food to the result before
			    adding it to the collection. </para>

			<para>If there are no foods with identical
			    <varname>date</varname> and
			    <varname>meal</varname> traits, then
			    <command>pantry</command> will set the
			    food's <varname>order</varname> trait to
			    <literal>0010</literal>.</para>

		    </listitem>
		</varlistentry>
            </variablelist>

	    <variablelist>
		<title>Meta</title>

		<varlistentry>
		    <term>
			<option>--help</option>
		    </term>
		    <term>
			<option>-h</option>
		    </term>

		    <listitem>
			<para>
                            Display brief help.
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--version</option>
		    </term>
		    <term>
			<option>-v</option>
		    </term>

		    <listitem>
			<para>
			    
                            Display Pantry version.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<option>--copyright</option>
		    </term>

		    <listitem>
			<para>

                            Display copyright information.

			</para>
		    </listitem>
		</varlistentry>
	    </variablelist>
        </refsect1>

	<refsect1>
	    <title>Reports</title>
	    <para>

                Two types of reports are available. Food reports are
                printed once per food in the buffer. Summary reports
                are printed once for the entire buffer.  To print
                more than one report, use multiple
                <option>--print</option> options. Report names may
                be abbreviated with an unambiguous specification of
                the first letters of the report. The following
                reports are available:

	    </para>

	    <variablelist>
		<title>Food reports</title>
		<varlistentry>
		    <term>
			<parameter>name</parameter>
		    </term>

		    <listitem>
			<para>
			    Food names
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>info</parameter>
		    </term>

		    <listitem>
			<para>

                            All traits other than the
                            <parameter>name</parameter>,
                            <parameter>yield</parameter>, and
                            <parameter>instructions</parameter>.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>recipe</parameter>
		    </term>

		    <listitem>
			<para>

                            <parameter>yield</parameter> and
                            <parameter>instructions</parameter>
                            traits, and the recipe's ingredients.
                            Ingredients are sorted according to
                            their <parameter>order</parameter>
                            traits.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>units</parameter>
		    </term>

		    <listitem>
			<para>
			    Available units.
			    <parameter>g</parameter>,
			    <parameter>oz</parameter>, and
			    <parameter>lb</parameter> are not
			    printed as these are available for every
			    food.
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>paste</parameter>
		    </term>

		    <listitem>
			<para>

			    Each food name, printed with one
			    available unit per line; quoted so that
			    output may be easily pasted into
			    subsequent <command>pantry</command>
			    commands.

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>blank</parameter>
		    </term>

		    <listitem>
			<para>
			    A blank line
			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>nuts</parameter>
		    </term>

		    <listitem>
			<para>

                            All of a food's nutrients

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>goals</parameter>
		    </term>

		    <listitem>
			<para>

                            Nutrients for which there is a goal
                            specified with <option>--goal</option>

			</para>
		    </listitem>
		</varlistentry>
            </variablelist>

            <variablelist>
                <title>Summary reports</title>

		<varlistentry>
		    <term>
			<parameter>groups</parameter>
		    </term>

		    <listitem>
			<para>

                            Number of foods in each food group, as
                            specified by each food's
                            <parameter>group</parameter> trait

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>Nuts</parameter>
		    </term>

		    <listitem>
			<para>

                            Sum of all nutrients in the buffer

			</para>
		    </listitem>
		</varlistentry>

		<varlistentry>
		    <term>
			<parameter>Goals</parameter>
		    </term>

		    <listitem>
			<para>

                            Sum of all nutrients in the buffer for
                            which there is a <option>--goal</option>

			</para>
		    </listitem>
		</varlistentry>
	    </variablelist>
	</refsect1>

        <refsect1 id="pantry-env-vars">
            <title>Environment variables</title>

            <variablelist>
                <varlistentry>
                    <term>PANTRY_SOCKET</term>
                    <listitem>

                        <para>If this environment variable is
                            specified, <command>pantry</command>
                            will use the path contained therein as
                            the filename of the socket where it will
                            attempt to connect to the
                            <command>pantryd</command> server.
                            PANTRY_SOCKET should contain the entire
                            path (beginning with
                            <filename>/</filename> ) and filename,
                            not just the directory for the socket.
                            The server must have already been
                            started with an identical value in its
                            PANTRY_SOCKET environment variable.
                        </para>

                        <para>If this environment variable is not
                            specified, <command>pantry</command>
                            will attempt to connect to a server at
                            the socket named 
                            <filename>$HOME/.pantrySocket</filename>.</para>
                    </listitem>
                </varlistentry>
            </variablelist>
        </refsect1>

	<refsect1 id='bugs'>
	    <title>Bugs</title>

            <para>Please help find them. Report bugs to 
                <email>omari@smileystation.com</email>.
	    </para>

            <para>Pantry has known limitations; see the Pantry User
                Guide for details.</para>

	</refsect1>

        <refsect1 id="pantry-home">
            <title>Pantry home page</title>

            <para><ulink url="http://www.smileystation.com/pantry"
                    /></para>

        </refsect1>

    </refentry>

    <refentry id="pantryd-man">
        <refentryinfo>
            <date>pb_release_date</date>
            <productname>Pantry</productname>
            <productnumber>pb_version</productnumber>
            <copyright><year>2007-2008</year><holder>Omari
                    Norman</holder></copyright>
        </refentryinfo>

        <refmeta>
            <refentrytitle>pantryd</refentrytitle>
            <manvolnum>1</manvolnum>
        </refmeta>

        <refnamediv>
            <refname>pantryd</refname>
            <refpurpose>nutrient tracking and analysis
                server</refpurpose>
        </refnamediv>

        <refsynopsisdiv>
            <cmdsynopsis>
                <command>pantryd</command>
                <arg rep="repeat">options</arg>
            </cmdsynopsis>
        </refsynopsisdiv>

        <refsect1 id="pantryd-description">
            <title>Description</title>

            <para><command>pantryd</command> is the server with
                which <command>pantry</command> communicates.
                <command>pantryd</command> must be running in order
                for any <command>pantry</command> commands to work.
            </para>

            <para>To start a server, simply execute
                <userinput>pantryd</userinput>. This will start a
                new server in the background, returning you to your
                command prompt. This server will keep running even
                if you logout of the shell from which you started
                the server. To kill the server, run
                <userinput>pantry --quit</userinput>. </para>
        </refsect1>

        <refsect1 id="pantryd-options">
            <title>Options</title>

            <variablelist>
                <varlistentry>
                    <term>
                        <option>--foreground</option>
                    </term>
                    <term>
                        <option>-f</option>
                    </term>

                    <listitem>
                        <para>

                            Run server in the foreground (useful for
                            debugging)

                        </para>
                    </listitem>
                </varlistentry>

                <varlistentry>
                    <term>
                        <option>--help</option>
                    </term>
                    <term>
                        <option>-h</option>
                    </term>

                    <listitem>
                        <para> Show brief help and exit</para>
                    </listitem>
                </varlistentry>
            </variablelist>
        </refsect1>

        <refsect1 id="pantryd-env-vars">
            <title>Environment variables</title>

            <variablelist>
                <varlistentry>
                    <term>PANTRY_SOCKET</term>
                    <listitem>

                        <para>If this environment variable is
                            specified, <command>pantryd</command>
                            will use the path contained therein as
                            the filename of the socket where it will
                            listen for connections. PANTRY_SOCKET
                            should contain the entire path
                            (beginning with <filename>/</filename> )
                            and filename, not just the directory for
                            the socket. To communicate with the
                            server, you'll need to make sure that
                            subsequent invocations of
                            <command>pantry</command> also have
                            their PANTRY_SOCKET environment variable
                            set to an identical value.</para>

                        <para>If this environment variable is not
                            specified, <command>pantryd</command>
                            will listen for connections on a socket
                            named
                            <filename>$HOME/.pantrySocket</filename>.</para>
                    </listitem>
                </varlistentry>
            </variablelist>
        </refsect1>

        <refsect1 id="pantryd-bugs">
            <title>Bugs</title>

            <para>Report any bugs to
                <email>omari@smileystation.com</email>.</para>
        </refsect1>

        <refsect1 id="pantryd-home">
            <title>Pantry home page</title>

            <para><ulink url="http://www.smileystation.com/pantry"
                    /></para>

        </refsect1>

    </refentry>
</appendix>

</book>

<!-- cleanup -->
pb_sh({pantry --quit >/dev/null 2>&1})
pb_sh({rm ~/my_pantry_file >/dev/null 2>&1})

<!-- vim: set expandtab ts=8 sts=4 sw=4 ai tw=68 fo+=t fdm=indent fdl=99 filetype=docbk: -->
